@@ -24,9 +24,11 @@ options:
     name:
         description:
             - Only show results for a specific account.
+        type: str
     resource_group:
         description:
             - Limit results to a resource group. Required when filtering by name.
+        type: str
         aliases:
             - resource_group_name
     tags:
@@ -61,20 +63,20 @@ author:
 '''
 
 EXAMPLES = '''
-    - name: Get facts for one account
-      azure_rm_storageaccount_info:
-        resource_group: myResourceGroup
-        name: clh0002
+- name: Get facts for one account
+  azure_rm_storageaccount_info:
+    resource_group: myResourceGroup
+    name: clh0002
 
-    - name: Get facts for all accounts in a resource group
-      azure_rm_storageaccount_info:
-        resource_group: myResourceGroup
+- name: Get facts for all accounts in a resource group
+  azure_rm_storageaccount_info:
+    resource_group: myResourceGroup
 
-    - name: Get facts for all accounts by tags
-      azure_rm_storageaccount_info:
-        tags:
-          - testing
-          - foo:bar
+- name: Get facts for all accounts by tags
+  azure_rm_storageaccount_info:
+    tags:
+      - testing
+      - foo:bar
 '''
 
 RETURN = '''
@@ -136,6 +138,25 @@ storageaccounts:
             returned: always
             type: str
             sample: Standard_ZRS
+        allow_cross_tenant_replication:
+            description:
+                - Allow or disallow cross AAD tenant object replication.
+            type: bool
+            returned: always
+            sample: true
+        allow_shared_key_access:
+            description:
+                - Indicates whether the storage account permits requests to be authorized with the account access key via Shared Key.
+            type: bool
+            returned: always
+            sample: true
+        default_to_o_auth_authentication:
+            description:
+                - A boolean flag which indicates whether the default authentication is OAuth or not.
+                - The default interpretation is false for this property.
+            type: bool
+            returned: always
+            sample: true
         custom_domain:
             description:
                 - User domain assigned to the storage account.
@@ -209,6 +230,12 @@ storageaccounts:
             type: bool
             returned: always
             sample: true
+        enable_nfs_v3:
+            description:
+                - NFS 3.0 protocol.
+            type: bool
+            returned: always
+            sample: false
         kind:
             description:
                 - The kind of storage.
@@ -477,6 +504,7 @@ storageaccounts:
                     description:
                         - The account key for the secondary_endpoints
                     sample: xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx
+                    type: str
         georeplication_stats:
             description:
                 - Parameters related to the status of geo-replication.
@@ -506,6 +534,12 @@ storageaccounts:
             returned: always
             type: dict
             sample: { "tag1": "abc" }
+        large_file_shares_state:
+            description:
+                - Allow large file shares if sets to Enabled.
+            type: str
+            returned: always
+            sample: Enabled
         static_website:
             description:
                 - Static website configuration for the storage account.
@@ -533,11 +567,6 @@ storageaccounts:
                     sample: error.html
 '''
 
-try:
-    from azure.core.exceptions import ResourceNotFoundError
-except Exception:
-    # This is handled in azure_rm_common
-    pass
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 from ansible.module_utils._text import to_native
@@ -676,6 +705,11 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
             public_network_access=account_obj.public_network_access,
             allow_blob_public_access=account_obj.allow_blob_public_access,
             is_hns_enabled=account_obj.is_hns_enabled if account_obj.is_hns_enabled else False,
+            large_file_shares_state=account_obj.large_file_shares_state,
+            enable_nfs_v3=account_obj.enable_nfs_v3 if hasattr(account_obj, 'enable_nfs_v3') else None,
+            allow_cross_tenant_replication=account_obj.allow_cross_tenant_replication,
+            allow_shared_key_access=account_obj.allow_shared_key_access,
+            default_to_o_auth_authentication=account_obj.default_to_o_auth_authentication,
             static_website=dict(
                 enabled=False,
                 index_document=None,
@@ -775,6 +809,11 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
                     account_dict['encryption']['services']['queue'] = dict(enabled=True)
                 if account_obj.encryption.services.blob:
                     account_dict['encryption']['services']['blob'] = dict(enabled=True)
+
+        account_dict['identity'] = dict()
+        if account_obj.identity:
+            account_dict['identity'] = account_obj.identity.as_dict()
+
         return account_dict
 
     def format_endpoint_dict(self, name, key, endpoint, storagetype, protocol='https'):
