@@ -50,6 +50,13 @@ options:
         representation of the object.
     type: str
     choices: ['uid', 'standard', 'full']
+  filter:
+    description:
+      - Search expression to filter objects by. The provided text should be exactly the same as it would be given in SmartConsole Object Explorer. The
+        logical operators in the expression ('AND', 'OR') should be provided in capital letters. The search involves both a IP search and a textual search in
+        name, comment, tags etc.
+    type: str
+    version_added: "6.4.0"
   limit:
     description:
       - No more than that many results will be returned.
@@ -77,6 +84,13 @@ options:
           - Sorts results by the given field in descending order.
         type: str
         choices: ['name']
+  domains_to_process:
+    description:
+      - Indicates which domains to process the commands on. It cannot be used with the details-level full, must be run from the System Domain only and
+        with ignore-warnings true. Valid values are, CURRENT_DOMAIN, ALL_DOMAINS_ON_THIS_SERVER.
+    type: list
+    elements: str
+    version_added: "6.4.0"
 extends_documentation_fragment: check_point.mgmt.checkpoint_facts
 """
 
@@ -110,6 +124,7 @@ def main():
     argument_spec = dict(
         name=dict(type="str"),
         details_level=dict(type="str", choices=["uid", "standard", "full"]),
+        filter=dict(type='str'),
         limit=dict(type="int"),
         offset=dict(type="int"),
         order=dict(
@@ -120,6 +135,7 @@ def main():
                 DESC=dict(type="str", choices=["name"]),
             ),
         ),
+        domains_to_process=dict(type='list', elements="str")
     )
     argument_spec.update(checkpoint_argument_spec_for_facts)
 
