@@ -4,14 +4,13 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+
 DOCUMENTATION = r"""
 ---
 module: event_email_config
 short_description: Resource module for Event Email Config
 description:
-- Manage operations create and update of the resource Event Email Config.
-- Create Email Destination.
-- Update Email Destination.
+- This module represents an alias of the module event_email_config_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -68,23 +67,24 @@ options:
     description: To Email.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
+- dnacentersdk >= 2.4.9
 - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management CreateEmailDestination
-  description: Complete reference of the CreateEmailDestination API.
+- name: Cisco DNA Center documentation for Event Management CreateEmailDestinationV1
+  description: Complete reference of the CreateEmailDestinationV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!create-email-destination
-- name: Cisco DNA Center documentation for Event Management UpdateEmailDestination
-  description: Complete reference of the UpdateEmailDestination API.
+- name: Cisco DNA Center documentation for Event Management UpdateEmailDestinationV1
+  description: Complete reference of the UpdateEmailDestinationV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!update-email-destination
 notes:
   - SDK Method used are
-    event_management.EventManagement.create_email_destination,
-    event_management.EventManagement.update_email_destination,
+    event_management.EventManagement.create_email_destination_v1,
+    event_management.EventManagement.update_email_destination_v1,
 
   - Paths used are
     post /dna/intent/api/v1/event/email-config,
     put /dna/intent/api/v1/event/email-config,
+  - It should be noted that this module is an alias of event_email_config_v1
 
 """
 
