@@ -4,15 +4,13 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+
 DOCUMENTATION = r"""
 ---
 module: event_subscription
 short_description: Resource module for Event Subscription
 description:
-- Manage operations create, update and delete of the resource Event Subscription.
-- Subscribe SubscriptionEndpoint to list of registered events Deprecated .
-- Delete EventSubscriptions.
-- Update SubscriptionEndpoint to list of registered events Deprecated .
+- This module represents an alias of the module event_subscription_v1
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -94,28 +92,29 @@ options:
     description: Subscriptions query parameter. List of EventSubscriptionId's for removal.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
+- dnacentersdk >= 2.4.9
 - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management CreateEventSubscriptions
-  description: Complete reference of the CreateEventSubscriptions API.
+- name: Cisco DNA Center documentation for Event Management CreateEventSubscriptionsV1
+  description: Complete reference of the CreateEventSubscriptionsV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!create-event-subscriptions
-- name: Cisco DNA Center documentation for Event Management DeleteEventSubscriptions
-  description: Complete reference of the DeleteEventSubscriptions API.
+- name: Cisco DNA Center documentation for Event Management DeleteEventSubscriptionsV1
+  description: Complete reference of the DeleteEventSubscriptionsV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!delete-event-subscriptions
-- name: Cisco DNA Center documentation for Event Management UpdateEventSubscriptions
-  description: Complete reference of the UpdateEventSubscriptions API.
+- name: Cisco DNA Center documentation for Event Management UpdateEventSubscriptionsV1
+  description: Complete reference of the UpdateEventSubscriptionsV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!update-event-subscriptions
 notes:
   - SDK Method used are
-    event_management.EventManagement.create_event_subscriptions,
-    event_management.EventManagement.delete_event_subscriptions,
-    event_management.EventManagement.update_event_subscriptions,
+    event_management.EventManagement.create_event_subscriptions_v1,
+    event_management.EventManagement.delete_event_subscriptions_v1,
+    event_management.EventManagement.update_event_subscriptions_v1,
 
   - Paths used are
     post /dna/intent/api/v1/event/subscription,
     delete /dna/intent/api/v1/event/subscription,
     put /dna/intent/api/v1/event/subscription,
+  - It should be noted that this module is an alias of event_subscription_v1
 
 """
 
