@@ -4,22 +4,20 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
+
 DOCUMENTATION = r"""
 ---
 module: interface_update
 short_description: Resource module for Interface Update
 description:
-- Manage operation update of the resource Interface Update.
-- >
-   Add/Update Interface description, VLAN membership, Voice VLAN and change Interface admin status 'UP'/'DOWN' from
-   Request body.
+- This module represents an alias of the module interface_update_v1
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   adminStatus:
-    description: Admin Status.
+    description: Admin status as ('UP'/'DOWN').
     type: str
   deploymentMode:
     description: DeploymentMode query parameter. Preview/Deploy 'Preview' means the
@@ -27,30 +25,31 @@ options:
       to the device.
     type: str
   description:
-    description: Description.
+    description: Description for the Interface.
     type: str
   interfaceUuid:
     description: InterfaceUuid path parameter. Interface ID.
     type: str
   vlanId:
-    description: Vlan Id.
+    description: VLAN Id to be Updated.
     type: int
   voiceVlanId:
-    description: Voice Vlan Id.
+    description: Voice Vlan Id to be Updated.
     type: int
 requirements:
-- dnacentersdk >= 2.5.5
+- dnacentersdk >= 2.4.9
 - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices UpdateInterfaceDetails
-  description: Complete reference of the UpdateInterfaceDetails API.
+- name: Cisco DNA Center documentation for Devices UpdateInterfaceDetailsV1
+  description: Complete reference of the UpdateInterfaceDetailsV1 API.
   link: https://developer.cisco.com/docs/dna-center/#!update-interface-details
 notes:
   - SDK Method used are
-    devices.Devices.update_interface_details,
+    devices.Devices.update_interface_details_v1,
 
   - Paths used are
     put /dna/intent/api/v1/interface/{interfaceUuid},
+  - It should be noted that this module is an alias of interface_update_v1
 
 """
 
@@ -72,7 +71,6 @@ EXAMPLES = r"""
     voiceVlanId: 0
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
