@@ -26,12 +26,14 @@ from ansible_collections.cisco.ise.plugins.plugin_utils.ise import (
 # Get common arguements specification
 argument_spec = ise_argument_spec()
 # Add arguments specific for this module
-argument_spec.update(dict(
-    name=dict(type="str"),
-    id=dict(type="str"),
-    page=dict(type="int"),
-    size=dict(type="int"),
-))
+argument_spec.update(
+    dict(
+        name=dict(type="str"),
+        id=dict(type="str"),
+        page=dict(type="int"),
+        size=dict(type="int"),
+    )
+)
 
 required_if = []
 required_one_of = []
@@ -42,7 +44,9 @@ required_together = []
 class ActionModule(ActionBase):
     def __init__(self, *args, **kwargs):
         if not ANSIBLE_UTILS_IS_INSTALLED:
-            raise AnsibleActionFail("ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'")
+            raise AnsibleActionFail(
+                "ansible.utils is not installed. Execute 'ansible-galaxy collection install ansible.utils'"
+            )
         super(ActionModule, self).__init__(*args, **kwargs)
         self._supports_async = False
         self._supports_check_mode = True
@@ -90,18 +94,18 @@ class ActionModule(ActionBase):
         if id:
             response = ise.exec(
                 family="tacacs_external_servers",
-                function='get_tacacs_external_servers_by_id',
-                params=self.get_object(self._task.args)
-            ).response['TacacsExternalServer']
+                function="get_tacacs_external_servers_by_id",
+                params=self.get_object(self._task.args),
+            ).response["TacacsExternalServer"]
             self._result.update(dict(ise_response=response))
             self._result.update(ise.exit_json())
             return self._result
         if name:
             response = ise.exec(
                 family="tacacs_external_servers",
-                function='get_tacacs_external_servers_by_name',
-                params=self.get_object(self._task.args)
-            ).response['TacacsExternalServer']
+                function="get_tacacs_external_servers_by_name",
+                params=self.get_object(self._task.args),
+            ).response["TacacsExternalServer"]
             self._result.update(dict(ise_response=response))
             self._result.update(ise.exit_json())
             return self._result
@@ -109,12 +113,12 @@ class ActionModule(ActionBase):
             responses = []
             generator = ise.exec(
                 family="tacacs_external_servers",
-                function='get_tacacs_external_servers_generator',
+                function="get_tacacs_external_servers_generator",
                 params=self.get_object(self._task.args),
             )
             try:
                 for item in generator:
-                    tmp_response = item.response['SearchResult']['resources']
+                    tmp_response = item.response["SearchResult"]["resources"]
                     if isinstance(tmp_response, list):
                         responses += tmp_response
                     else:
