@@ -161,7 +161,6 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     get_config,
     load_config,
-    nxos_argument_spec,
     run_commands,
 )
 
@@ -199,7 +198,6 @@ def flatten_list(command_lists):
 
 
 def get_vrf_list(module):
-
     try:
         body = run_commands(module, ["show vrf all | json"])[0]
         vrf_table = body["TABLE_vrf"]["ROW_vrf"]
@@ -370,8 +368,6 @@ def main():
         state=dict(choices=["absent", "present"], default="present"),
     )
 
-    argument_spec.update(nxos_argument_spec)
-
     mutually_exclusive = [("auto_recovery", "auto_recovery_reload_delay")]
     module = AnsibleModule(
         argument_spec=argument_spec,
