@@ -85,7 +85,7 @@ def get_provider_informations(providers):
 
         for provider in providers:
             add_init_py(os.path.join('plugins', 'module_utils', provider))
-            full_py_path = 'ansible_collections.community.dns.plugins.module_utils.{0}.api'.format(provider)
+            full_py_path = f'ansible_collections.community.dns.plugins.module_utils.{provider}.api'
             full_pathname = os.path.join('plugins', 'module_utils', provider, 'api.py')
             try:
                 loader = importlib.machinery.SourceFileLoader(full_py_path, full_pathname)
@@ -93,17 +93,17 @@ def get_provider_informations(providers):
                 the_module = importlib.util.module_from_spec(spec)
                 loader.exec_module(the_module)
             except Exception as e:
-                errors.append('{0}: Error while importing module {1}: {2}'.format(full_pathname, full_py_path, e))
+                errors.append(f'{full_pathname}: Error while importing module {full_py_path}: {e}')
                 continue
 
-            create_provider_info_fn_name = 'create_{0}_provider_information'.format(provider)
+            create_provider_info_fn_name = f'create_{provider}_provider_information'
             try:
                 create_provider_info_fn = provider_information = the_module.__dict__[create_provider_info_fn_name]
                 provider_infos[provider] = create_provider_info_fn()
             except KeyError as e:
-                errors.append('{0}: Cannot find function {1}'.format(full_pathname, create_provider_info_fn))
+                errors.append(f'{full_pathname}: Cannot find function {create_provider_info_fn}')
             except Exception as e:
-                errors.append('{0}: Error while invoking function {1}: {2}'.format(full_pathname, create_provider_info_fn, e))
+                errors.append(f'{full_pathname}: Error while invoking function {create_provider_info_fn}: {e}')
 
         return provider_infos, errors
     finally:
@@ -115,10 +115,10 @@ class DocFragmentParseError(Exception):
     def __init__(self, path, error_message):
         self.path = path
         self.error_message = error_message
-        super(DocFragmentParseError, self).__init__('Error while parsing {0}: {1}'.format(path, error_message))
+        super(DocFragmentParseError, self).__init__(f'Error while parsing {path}: {error_message}')
 
 
-DOC_FRAGMENT_START_MATCHER = re.compile(r"^    ([A-Z_]+) = r'''$")
+DOC_FRAGMENT_START_MATCHER = re.compile(r'^    ([A-Z_]+) = r"""$')
 
 
 class Dumper(yaml.SafeDumper):
@@ -126,7 +126,7 @@ class Dumper(yaml.SafeDumper):
         return True
 
     def increase_indent(self, flow=False, *args, **kwargs):
-        self.best_indent = kwargs.pop('ident_override', 4)
+        self.best_indent = kwargs.pop('ident_override', 2)
         return super().increase_indent(*args, **kwargs)
 
     def expect_block_sequence(self):
@@ -143,14 +143,14 @@ class DocFragment:
         try:
             self.data = yaml.safe_load('\n'.join(self.lines))
         except Exception as e:
-            raise DocFragmentParseError(path, 'Error while parsing part {0}: {1}'.format(name, e))
+            raise DocFragmentParseError(path, f'Error while parsing part {name}: {e}')
 
     def recreate_lines(self):
-        data = yaml.dump(self.data, default_flow_style=False, indent=4, Dumper=Dumper, sort_keys=False)
+        data = yaml.dump(self.data, default_flow_style=False, indent=2, Dumper=Dumper, sort_keys=False)
         self.lines = data.splitlines()
 
     def serialize_lines(self):
-        return self.prefix_lines + ["    {0} = r'''".format(self.name)] + self.lines + ["'''"]
+        return self.prefix_lines + [f'    {self.name} = r"""'] + self.lines + ['"""']
 
 
 class DocFragmentFile:
@@ -178,7 +178,7 @@ class DocFragmentFile:
                         body_name = m.group(1)
                     else:
                         body_prefix.append(line)
-                elif line == "'''":
+                elif line == '"""':
                     fragment = DocFragment(path, body_prefix, body_name, body_lines)
                     self.fragments.append(fragment)
                     self.fragments_by_name[body_name] = fragment
@@ -201,7 +201,7 @@ class DocFragmentFile:
 
 
 def doc_fragment_fn(name):
-    return os.path.join('plugins', 'doc_fragments', '{0}.py'.format(name))
+    return os.path.join('plugins', 'doc_fragments', f'{name}.py')
 
 
 def load_doc_fragment(name):
@@ -273,7 +273,7 @@ def augment_fragment(provider_fragment, provider_info):
             '    # WARNING: This section is automatically generated by update-docs-fragments.py.',
         ]
         insertion_fragment.prefix_lines.extend([
-            '    #          {0}'.format(line)
+            f'    #          {line}'
             for line in textwrap.wrap(
                 'It is used to augment the docs fragment{0} {1}.'.format(
                     's' if len(all_doc_fragment_names) != 1 else '',
@@ -297,16 +297,16 @@ def main(program, arguments):
                 if not compare_doc_fragment(provider, doc_fragment):
                     path = doc_fragment_fn(provider)
                     if lint:
-                        errors.append('{0}: Needs to be updated by update-docs-fragments.py'.format(path))
+                        errors.append(f'{path}: Needs to be updated by update-docs-fragments.py')
                     else:
-                        print('Writing {0}...'.format(path))
+                        print(f'Writing {path}...')
                         write_doc_fragment(provider, doc_fragment)
 
             except DocFragmentParseError as e:
-                errors.append('{0}: Error while parsing docs fragment: {1}'.format(e.path, e.error_message))
+                errors.append(f'{e.path}: Error while parsing docs fragment: {e.error_message}')
 
     except Exception as e:
-        errors.append('{0}: Unexpected error: {1}'.format(program, e))
+        errors.append(f'{program}: Unexpected error: {e}')
 
     for error in errors:
         print(error)
