@@ -9,61 +9,60 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 DOCUMENTATION = r"""
----
 module: copr
 short_description: Manage one of the Copr repositories
 version_added: 2.0.0
 description: This module can enable, disable or remove the specified repository.
 author: Silvie Chlupova (@schlupov) <schlupov@redhat.com>
 requirements:
-    - dnf
-    - dnf-plugins-core
+  - dnf
+  - dnf-plugins-core
 notes:
-    - Supports C(check_mode).
+  - Supports C(check_mode).
 extends_documentation_fragment:
-    - community.general.attributes
+  - community.general.attributes
 attributes:
-    check_mode:
-        support: full
-    diff_mode:
-        support: none
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
 options:
-    host:
-        description: The Copr host to work with.
-        default: copr.fedorainfracloud.org
-        type: str
-    protocol:
-        description: This indicate which protocol to use with the host.
-        default: https
-        type: str
-    name:
-        description: Copr directory name, for example C(@copr/copr-dev).
-        required: true
-        type: str
-    state:
-        description:
-            - Whether to set this project as V(enabled), V(disabled), or V(absent).
-        default: enabled
-        type: str
-        choices: [absent, enabled, disabled]
-    chroot:
-        description:
-            - The name of the chroot that you want to enable/disable/remove in the project,
-              for example V(epel-7-x86_64). Default chroot is determined by the operating system,
-              version of the operating system, and architecture on which the module is run.
-        type: str
-    includepkgs:
-        description: List of packages to include.
-        required: false
-        type: list
-        elements: str
-        version_added: 9.4.0
-    excludepkgs:
-        description: List of packages to exclude.
-        required: false
-        type: list
-        elements: str
-        version_added: 9.4.0
+  host:
+    description: The Copr host to work with.
+    default: copr.fedorainfracloud.org
+    type: str
+  protocol:
+    description: This indicate which protocol to use with the host.
+    default: https
+    type: str
+  name:
+    description: Copr directory name, for example C(@copr/copr-dev).
+    required: true
+    type: str
+  state:
+    description:
+      - Whether to set this project as V(enabled), V(disabled), or V(absent).
+    default: enabled
+    type: str
+    choices: [absent, enabled, disabled]
+  chroot:
+    description:
+      - The name of the chroot that you want to enable/disable/remove in the project, for example V(epel-7-x86_64). Default
+        chroot is determined by the operating system, version of the operating system, and architecture on which the module
+        is run.
+    type: str
+  includepkgs:
+    description: List of packages to include.
+    required: false
+    type: list
+    elements: str
+    version_added: 9.4.0
+  excludepkgs:
+    description: List of packages to exclude.
+    required: false
+    type: list
+    elements: str
+    version_added: 9.4.0
 """
 
 EXAMPLES = r"""
