@@ -22,6 +22,10 @@ __metaclass__ = type
 DOCUMENTATION = '''
 ---
 module: ce_snmp_target_host
+deprecated:
+  removed_in: 6.0.0
+  why: This collection and all content in it is unmaintained and deprecated.
+  alternative: Unknown.
 short_description: Manages SNMP target host configuration on HUAWEI CloudEngine switches.
 description:
     - Manages SNMP target host configurations on HUAWEI CloudEngine switches.
@@ -84,7 +88,7 @@ EXAMPLES = '''
 - name: CloudEngine snmp target host test
   hosts: cloudengine
   connection: local
-  gather_facts: no
+  gather_facts: false
 
   tasks:
 
