@@ -9,6 +9,10 @@ __metaclass__ = type
 
 DOCUMENTATION = r'''
     name: vmware_vm_inventory
+    deprecated:
+      removed_in: 7.0.0
+      why: This module has been moved to the L(new vmware.vmware collection,https://forum.ansible.com/t/5880)
+      alternative: Use P(vmware.vmware.vms#inventory) instead.
     short_description: VMware Guest inventory source
     author:
       - Abhijeet Kasurde (@Akasurde)
@@ -695,6 +699,8 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         """
         super(InventoryModule, self).parse(inventory, loader, path, cache=cache)
 
+        cacheable_results = None
+
         cache_key = self.get_cache_key(path)
 
         config_data = self._read_config_data(path)
