@@ -118,7 +118,6 @@ dvs_portgroup_info:
                     "live_port_move": false,
                     "network_rp_override": false,
                     "port_config_reset_at_disconnect": true,
-                    "security_override": false,
                     "shaping_override": false,
                     "traffic_filter_override": false,
                     "uplink_teaming_override": false,
@@ -265,7 +264,6 @@ class DVSPortgroupInfoManager(PyVmomi):
                         live_port_move=dvs_pg.config.policy.livePortMovingAllowed,
                         network_rp_override=dvs_pg.config.policy.networkResourcePoolOverrideAllowed,
                         port_config_reset_at_disconnect=dvs_pg.config.policy.portConfigResetAtDisconnect,
-                        security_override=dvs_pg.config.policy.macManagementOverrideAllowed,
                         shaping_override=dvs_pg.config.policy.shapingOverrideAllowed,
                         traffic_filter_override=dvs_pg.config.policy.trafficFilterOverrideAllowed,
                         uplink_teaming_override=dvs_pg.config.policy.uplinkTeamingOverrideAllowed,
