@@ -22,17 +22,17 @@ options:
    name:
         description:
             - Name of the existing virtual machine to move.
-            - This is required if C(uuid) or C(moid) is not supplied.
+            - This is required if O(uuid) or O(moid) is not supplied.
         type: str
    uuid:
         description:
             - UUID of the virtual machine to manage if known, this is VMware's unique identifier.
-            - This is required if C(name) or C(moid) is not supplied.
+            - This is required if O(name) or O(moid) is not supplied.
         type: str
    moid:
         description:
             - Managed Object ID of the instance to manage if known, this is a unique identifier only within a single vCenter instance.
-            - This is required if C(name) or C(uuid) is not supplied.
+            - This is required if O(name) or O(uuid) is not supplied.
         type: str
    use_instance_uuid:
         description:
@@ -49,7 +49,6 @@ options:
         description:
             - Absolute path to move an existing guest
             - The dest_folder should include the datacenter. ESX's datacenter is ha-datacenter.
-            - This parameter is case sensitive.
             - 'Examples:'
             - '   dest_folder: /ha-datacenter/vm'
             - '   dest_folder: ha-datacenter/vm'
