@@ -93,15 +93,17 @@ options:
                 type: str
                 description: CASB profile name.
                 required: true
-            saas-application:
+            saas_application:
+                aliases: ['saas-application']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to saas_application. Saas application.
+                description: Saas application.
                 suboptions:
-                    access-rule:
+                    access_rule:
+                        aliases: ['access-rule']
                         type: list
                         elements: dict
-                        description: Deprecated, please rename it to access_rule. Access rule.
+                        description: Access rule.
                         suboptions:
                             action:
                                 type: str
@@ -123,10 +125,32 @@ options:
                             name:
                                 type: str
                                 description: CASB access rule activity name.
-                    custom-control:
+                            attribute_filter:
+                                aliases: ['attribute-filter']
+                                type: list
+                                elements: dict
+                                description: Attribute filter.
+                                suboptions:
+                                    action:
+                                        type: str
+                                        description: CASB access rule tenant control action.
+                                        choices:
+                                            - 'block'
+                                            - 'monitor'
+                                            - 'bypass'
+                                    attribute_match:
+                                        aliases: ['attribute-match']
+                                        type: list
+                                        elements: str
+                                        description: CASB access rule tenant match.
+                                    id:
+                                        type: int
+                                        description: CASB tenant control ID.
+                    custom_control:
+                        aliases: ['custom-control']
                         type: list
                         elements: dict
-                        description: Deprecated, please rename it to custom_control. Custom control.
+                        description: Custom control.
                         suboptions:
                             name:
                                 type: str
@@ -139,20 +163,44 @@ options:
                                     name:
                                         type: str
                                         description: CASB custom control option name.
-                                    user-input:
+                                    user_input:
+                                        aliases: ['user-input']
                                         type: list
                                         elements: str
-                                        description: Deprecated, please rename it to user_input. CASB custom control user input.
-                    domain-control:
+                                        description: CASB custom control user input.
+                            attribute_filter:
+                                aliases: ['attribute-filter']
+                                type: list
+                                elements: dict
+                                description: Attribute filter.
+                                suboptions:
+                                    action:
+                                        type: str
+                                        description: CASB access rule tenant control action.
+                                        choices:
+                                            - 'block'
+                                            - 'monitor'
+                                            - 'bypass'
+                                    attribute_match:
+                                        aliases: ['attribute-match']
+                                        type: list
+                                        elements: str
+                                        description: CASB access rule tenant match.
+                                    id:
+                                        type: int
+                                        description: CASB tenant control ID.
+                    domain_control:
+                        aliases: ['domain-control']
                         type: str
-                        description: Deprecated, please rename it to domain_control. Enable/disable domain control.
+                        description: Enable/disable domain control.
                         choices:
                             - 'disable'
                             - 'enable'
-                    domain-control-domains:
+                    domain_control_domains:
+                        aliases: ['domain-control-domains']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to domain_control_domains. CASB profile domain control domains.
+                        description: CASB profile domain control domains.
                     log:
                         type: str
                         description: Enable/disable log settings.
@@ -162,32 +210,58 @@ options:
                     name:
                         type: str
                         description: CASB profile SaaS application name.
-                    safe-search:
+                    safe_search:
+                        aliases: ['safe-search']
                         type: str
-                        description: Deprecated, please rename it to safe_search. Enable/disable safe search.
+                        description: Enable/disable safe search.
                         choices:
                             - 'disable'
                             - 'enable'
-                    safe-search-control:
+                    safe_search_control:
+                        aliases: ['safe-search-control']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to safe_search_control. CASB profile safe search control.
-                    tenant-control:
+                        description: CASB profile safe search control.
+                    tenant_control:
+                        aliases: ['tenant-control']
                         type: str
-                        description: Deprecated, please rename it to tenant_control. Enable/disable tenant control.
+                        description: Enable/disable tenant control.
                         choices:
                             - 'disable'
                             - 'enable'
-                    tenant-control-tenants:
+                    tenant_control_tenants:
+                        aliases: ['tenant-control-tenants']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to tenant_control_tenants. CASB profile tenant control tenants.
+                        description: CASB profile tenant control tenants.
                     status:
                         type: str
                         description: Enable/disable setting.
                         choices:
                             - 'disable'
                             - 'enable'
+                    advanced_tenant_control:
+                        aliases: ['advanced-tenant-control']
+                        type: list
+                        elements: dict
+                        description: Advanced tenant control.
+                        suboptions:
+                            attribute:
+                                type: list
+                                elements: dict
+                                description: Attribute.
+                                suboptions:
+                                    input:
+                                        type: list
+                                        elements: str
+                                        description: CASB extend user input value.
+                                    name:
+                                        type: str
+                                        description: CASB extend user input name.
+                            name:
+                                type: list
+                                elements: str
+                                description: CASB advanced tenant control name.
             comment:
                 type: str
                 description: Comment.
@@ -219,12 +293,17 @@ EXAMPLES = '''
                 -
                   action: <value in [block, bypass, monitor]>
                   bypass:
-                    - av
-                    - dlp
-                    - web-filter
-                    - file-filter
-                    - video-filter
+                    - "av"
+                    - "dlp"
+                    - "web-filter"
+                    - "file-filter"
+                    - "video-filter"
                   name: <string>
+                  attribute_filter:
+                    -
+                      action: <value in [block, monitor, bypass]>
+                      attribute_match: <list or string>
+                      id: <integer>
               custom_control:
                 -
                   name: <string>
@@ -232,6 +311,11 @@ EXAMPLES = '''
                     -
                       name: <string>
                       user_input: <list or string>
+                  attribute_filter:
+                    -
+                      action: <value in [block, monitor, bypass]>
+                      attribute_match: <list or string>
+                      id: <integer>
               domain_control: <value in [disable, enable]>
               domain_control_domains: <list or string>
               log: <value in [disable, enable]>
@@ -241,6 +325,13 @@ EXAMPLES = '''
               tenant_control: <value in [disable, enable]>
               tenant_control_tenants: <list or string>
               status: <value in [disable, enable]>
+              advanced_tenant_control:
+                -
+                  attribute:
+                    -
+                      input: <list or string>
+                      name: <string>
+                  name: <list or string>
           comment: <string>
 '''
 
@@ -285,23 +376,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/casb/profile',
         '/pm/config/global/obj/casb/profile'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/casb/profile/{profile}',
-        '/pm/config/global/obj/casb/profile/{profile}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -326,7 +409,17 @@ def main():
                                     'choices': ['av', 'dlp', 'web-filter', 'file-filter', 'video-filter'],
                                     'elements': 'str'
                                 },
-                                'name': {'v_range': [['7.4.1', '']], 'type': 'str'}
+                                'name': {'v_range': [['7.4.1', '']], 'type': 'str'},
+                                'attribute-filter': {
+                                    'v_range': [['7.6.2', '']],
+                                    'type': 'list',
+                                    'options': {
+                                        'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor', 'bypass'], 'type': 'str'},
+                                        'attribute-match': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                        'id': {'v_range': [['7.6.2', '']], 'type': 'int'}
+                                    },
+                                    'elements': 'dict'
+                                }
                             },
                             'elements': 'dict'
                         },
@@ -343,6 +436,16 @@ def main():
                                         'user-input': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'}
                                     },
                                     'elements': 'dict'
+                                },
+                                'attribute-filter': {
+                                    'v_range': [['7.6.2', '']],
+                                    'type': 'list',
+                                    'options': {
+                                        'action': {'v_range': [['7.6.2', '']], 'choices': ['block', 'monitor', 'bypass'], 'type': 'str'},
+                                        'attribute-match': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                        'id': {'v_range': [['7.6.2', '']], 'type': 'int'}
+                                    },
+                                    'elements': 'dict'
                                 }
                             },
                             'elements': 'dict'
@@ -355,13 +458,29 @@ def main():
                         'safe-search-control': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'},
                         'tenant-control': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                         'tenant-control-tenants': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'},
-                        'status': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'status': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'advanced-tenant-control': {
+                            'v_range': [['7.6.2', '']],
+                            'type': 'list',
+                            'options': {
+                                'attribute': {
+                                    'v_range': [['7.6.2', '']],
+                                    'type': 'list',
+                                    'options': {
+                                        'input': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                                        'name': {'v_range': [['7.6.2', '']], 'type': 'str'}
+                                    },
+                                    'elements': 'dict'
+                                },
+                                'name': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'}
+                            },
+                            'elements': 'dict'
+                        }
                     },
                     'elements': 'dict'
                 },
                 'comment': {'v_range': [['7.4.3', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -375,9 +494,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
