@@ -111,9 +111,10 @@ options:
                     - 'new'
                     - 'new-on-not-found'
                     - 'delete'
-            case-sensitive:
+            case_sensitive:
+                aliases: ['case-sensitive']
                 type: str
-                description: Deprecated, please rename it to case_sensitive. CASB operation search case sensitive.
+                description: CASB operation search case sensitive.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -122,19 +123,23 @@ options:
                 description: CASB operation direction.
                 choices:
                     - 'request'
-            header-name:
+                    - 'response'
+            header_name:
+                aliases: ['header-name']
                 type: str
-                description: Deprecated, please rename it to header_name. CASB operation header name to search.
+                description: CASB operation header name to search.
             name:
                 type: str
                 description: CASB control option operation name.
                 required: true
-            search-key:
+            search_key:
+                aliases: ['search-key']
                 type: str
-                description: Deprecated, please rename it to search_key. CASB operation key to search.
-            search-pattern:
+                description: CASB operation key to search.
+            search_pattern:
+                aliases: ['search-pattern']
                 type: str
-                description: Deprecated, please rename it to search_pattern. CASB operation search pattern.
+                description: CASB operation search pattern.
                 choices:
                     - 'simple'
                     - 'substr'
@@ -145,9 +150,11 @@ options:
                 choices:
                     - 'header'
                     - 'path'
-            value-from-input:
+                    - 'body'
+            value_from_input:
+                aliases: ['value-from-input']
                 type: str
-                description: Deprecated, please rename it to value_from_input. Enable/disable value from user input.
+                description: Enable/disable value from user input.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -180,12 +187,12 @@ EXAMPLES = '''
         casb_useractivity_controloptions_operations:
           action: <value in [append, prepend, replace, ...]>
           case_sensitive: <value in [disable, enable]>
-          direction: <value in [request]>
+          direction: <value in [request, response]>
           header_name: <string>
           name: <string>
           search_key: <string>
           search_pattern: <value in [simple, substr, regexp]>
-          target: <value in [header, path]>
+          target: <value in [header, path, body]>
           value_from_input: <value in [disable, enable]>
           values: <list or string>
 '''
@@ -231,23 +238,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/casb/user-activity/{user-activity}/control-options/{control-options}/operations',
         '/pm/config/global/obj/casb/user-activity/{user-activity}/control-options/{control-options}/operations'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/casb/user-activity/{user-activity}/control-options/{control-options}/operations/{operations}',
-        '/pm/config/global/obj/casb/user-activity/{user-activity}/control-options/{control-options}/operations/{operations}'
-    ]
-
     url_params = ['adom', 'user-activity', 'control-options']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -262,16 +261,15 @@ def main():
             'options': {
                 'action': {'v_range': [['7.4.1', '']], 'choices': ['append', 'prepend', 'replace', 'new', 'new-on-not-found', 'delete'], 'type': 'str'},
                 'case-sensitive': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'direction': {'v_range': [['7.4.1', '']], 'choices': ['request'], 'type': 'str'},
+                'direction': {'v_range': [['7.4.1', '']], 'choices': ['request', 'response'], 'type': 'str'},
                 'header-name': {'v_range': [['7.4.1', '']], 'type': 'str'},
                 'name': {'v_range': [['7.4.1', '']], 'required': True, 'type': 'str'},
                 'search-key': {'v_range': [['7.4.1', '']], 'no_log': True, 'type': 'str'},
                 'search-pattern': {'v_range': [['7.4.1', '']], 'choices': ['simple', 'substr', 'regexp'], 'type': 'str'},
-                'target': {'v_range': [['7.4.1', '']], 'choices': ['header', 'path'], 'type': 'str'},
+                'target': {'v_range': [['7.4.1', '']], 'choices': ['header', 'path', 'body'], 'type': 'str'},
                 'value-from-input': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'values': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'}
             }
-
         }
     }
 
@@ -285,9 +283,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
