@@ -99,9 +99,10 @@ options:
         required: false
         type: dict
         suboptions:
-            case-sensitive:
+            case_sensitive:
+                aliases: ['case-sensitive']
                 type: str
-                description: Deprecated, please rename it to case_sensitive. CASB user activity match case sensitive.
+                description: CASB user activity match case sensitive.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -109,23 +110,26 @@ options:
                 type: list
                 elements: str
                 description: CASB user activity domain list.
-            header-name:
+            header_name:
+                aliases: ['header-name']
                 type: str
-                description: Deprecated, please rename it to header_name. CASB user activity rule header name.
+                description: CASB user activity rule header name.
             id:
                 type: int
                 description: CASB user activity rule ID.
                 required: true
-            match-pattern:
+            match_pattern:
+                aliases: ['match-pattern']
                 type: str
-                description: Deprecated, please rename it to match_pattern. CASB user activity rule match pattern.
+                description: CASB user activity rule match pattern.
                 choices:
                     - 'simple'
                     - 'substr'
                     - 'regexp'
-            match-value:
+            match_value:
+                aliases: ['match-value']
                 type: str
-                description: Deprecated, please rename it to match_value. CASB user activity rule match value.
+                description: CASB user activity rule match value.
             methods:
                 type: list
                 elements: str
@@ -146,6 +150,16 @@ options:
                     - 'header'
                     - 'header-value'
                     - 'method'
+                    - 'body'
+            body_type:
+                aliases: ['body-type']
+                type: str
+                description: CASB user activity match rule body type.
+                choices:
+                    - 'json'
+            jq:
+                type: str
+                description: CASB user activity rule match jq script.
 '''
 
 EXAMPLES = '''
@@ -178,6 +192,8 @@ EXAMPLES = '''
           methods: <list or string>
           negate: <value in [disable, enable]>
           type: <value in [domains, host, path, ...]>
+          body_type: <value in [json]>
+          jq: <string>
 '''
 
 RETURN = '''
@@ -221,23 +237,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/casb/user-activity/{user-activity}/match/{match}/rules',
         '/pm/config/global/obj/casb/user-activity/{user-activity}/match/{match}/rules'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/casb/user-activity/{user-activity}/match/{match}/rules/{rules}',
-        '/pm/config/global/obj/casb/user-activity/{user-activity}/match/{match}/rules/{rules}'
-    ]
-
     url_params = ['adom', 'user-activity', 'match']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -257,9 +265,10 @@ def main():
                 'match-value': {'v_range': [['7.4.1', '']], 'type': 'str'},
                 'methods': {'v_range': [['7.4.1', '']], 'type': 'list', 'elements': 'str'},
                 'negate': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'type': {'v_range': [['7.4.1', '']], 'choices': ['domains', 'host', 'path', 'header', 'header-value', 'method'], 'type': 'str'}
+                'type': {'v_range': [['7.4.1', '']], 'choices': ['domains', 'host', 'path', 'header', 'header-value', 'method', 'body'], 'type': 'str'},
+                'body-type': {'v_range': [['7.6.2', '']], 'choices': ['json'], 'type': 'str'},
+                'jq': {'v_range': [['7.6.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -273,9 +282,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
