@@ -89,9 +89,10 @@ options:
         required: false
         type: dict
         suboptions:
-            domain-name:
+            domain_name:
+                aliases: ['domain-name']
                 type: str
-                description: Deprecated, please rename it to domain_name. Fully qualified domain name
+                description: Fully qualified domain name
             ip:
                 type: str
                 description: IPv4 server address.
@@ -104,9 +105,10 @@ options:
             port:
                 type: int
                 description: Port number of service.
-            server-name:
+            server_name:
+                aliases: ['server-name']
                 type: str
-                description: Deprecated, please rename it to server_name. Name of the server to connect to.
+                description: Name of the server to connect to.
             username:
                 type: str
                 description: User name to sign in with.
@@ -181,23 +183,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/cifs/domain-controller',
         '/pm/config/global/obj/cifs/domain-controller'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/cifs/domain-controller/{domain-controller}',
-        '/pm/config/global/obj/cifs/domain-controller/{domain-controller}'
-    ]
-
     url_params = ['adom']
     module_primary_key = None
     module_arg_spec = {
@@ -214,7 +208,6 @@ def main():
                 'server-name': {'v_range': [['6.2.0', '']], 'type': 'str'},
                 'username': {'v_range': [['6.2.0', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -228,9 +221,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
