@@ -96,9 +96,10 @@ options:
             port:
                 type: int
                 description: SMTP server port.
-            reply-to:
+            reply_to:
+                aliases: ['reply-to']
                 type: str
-                description: Deprecated, please rename it to reply_to. Reply-To email address.
+                description: Reply-To email address.
             security:
                 type: str
                 description: Connection security used by the email server.
@@ -109,15 +110,18 @@ options:
             server:
                 type: str
                 description: SMTP server IP address or hostname.
-            source-ip:
+            source_ip:
+                aliases: ['source-ip']
                 type: str
-                description: Deprecated, please rename it to source_ip. SMTP server IPv4 source IP.
-            source-ip6:
+                description: SMTP server IPv4 source IP.
+            source_ip6:
+                aliases: ['source-ip6']
                 type: str
-                description: Deprecated, please rename it to source_ip6. SMTP server IPv6 source IP.
-            ssl-min-proto-version:
+                description: SMTP server IPv6 source IP.
+            ssl_min_proto_version:
+                aliases: ['ssl-min-proto-version']
                 type: str
-                description: Deprecated, please rename it to ssl_min_proto_version. Minimum supported protocol version for SSL/TLS connections
+                description: Minimum supported protocol version for SSL/TLS connections
                 choices:
                     - 'default'
                     - 'TLSv1'
@@ -133,22 +137,28 @@ options:
             username:
                 type: str
                 description: SMTP server user name for authentication.
-            validate-server:
+            validate_server:
+                aliases: ['validate-server']
                 type: str
-                description: Deprecated, please rename it to validate_server. Enable/disable validation of server certificate.
+                description: Enable/disable validation of server certificate.
                 choices:
                     - 'disable'
                     - 'enable'
             interface:
                 type: str
                 description: Specify outgoing interface to reach server.
-            interface-select-method:
+            interface_select_method:
+                aliases: ['interface-select-method']
                 type: str
-                description: Deprecated, please rename it to interface_select_method. Specify how to select outgoing interface to reach server.
+                description: Specify how to select outgoing interface to reach server.
                 choices:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
+            vrf_select:
+                aliases: ['vrf-select']
+                type: int
+                description: VRF ID used for connection to server.
 '''
 
 EXAMPLES = '''
@@ -184,6 +194,7 @@ EXAMPLES = '''
           validate_server: <value in [disable, enable]>
           interface: <string>
           interface_select_method: <value in [auto, sdwan, specify]>
+          vrf_select: <integer>
 '''
 
 RETURN = '''
@@ -227,21 +238,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/system/email-server'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/system/email-server/{email-server}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = None
     module_arg_spec = {
@@ -268,9 +272,9 @@ def main():
                 'username': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
                 'validate-server': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'interface': {'v_range': [['7.0.0', '']], 'type': 'str'},
-                'interface-select-method': {'v_range': [['7.0.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'}
+                'interface-select-method': {'v_range': [['7.0.0', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -284,9 +288,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
