@@ -106,9 +106,10 @@ options:
             key:
                 type: raw
                 description: (list) Key for MD5 authentication.
-            key-id:
+            key_id:
+                aliases: ['key-id']
                 type: int
-                description: Deprecated, please rename it to key_id. Key ID for authentication.
+                description: Key ID for authentication.
             ntpv3:
                 type: str
                 description: Enable to use NTPv3 instead of NTPv4.
@@ -121,27 +122,34 @@ options:
             interface:
                 type: str
                 description: Specify outgoing interface to reach server.
-            interface-select-method:
+            interface_select_method:
+                aliases: ['interface-select-method']
                 type: str
-                description: Deprecated, please rename it to interface_select_method. Specify how to select outgoing interface to reach server.
+                description: Specify how to select outgoing interface to reach server.
                 choices:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
-            ip-type:
+            ip_type:
+                aliases: ['ip-type']
                 type: str
-                description: Deprecated, please rename it to ip_type. Choose to connect to IPv4 or/and IPv6 NTP server.
+                description: Choose to connect to IPv4 or/and IPv6 NTP server.
                 choices:
                     - 'IPv6'
                     - 'IPv4'
                     - 'Both'
-            key-type:
+            key_type:
+                aliases: ['key-type']
                 type: str
-                description: Deprecated, please rename it to key_type. Select NTP authentication type.
+                description: Select NTP authentication type.
                 choices:
                     - 'SHA1'
                     - 'SHA256'
                     - 'MD5'
+            vrf_select:
+                aliases: ['vrf-select']
+                type: int
+                description: VRF ID used for connection to server.
 '''
 
 EXAMPLES = '''
@@ -174,6 +182,7 @@ EXAMPLES = '''
           interface_select_method: <value in [auto, sdwan, specify]>
           ip_type: <value in [IPv6, IPv4, Both]>
           key_type: <value in [SHA1, SHA256, MD5]>
+          vrf_select: <integer>
 '''
 
 RETURN = '''
@@ -217,21 +226,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/devprof/{devprof}/system/ntp/ntpserver'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/devprof/{devprof}/system/ntp/ntpserver/{ntpserver}'
-    ]
-
     url_params = ['adom', 'devprof']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -247,16 +249,16 @@ def main():
                 'key-id': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'no_log': True, 'type': 'int'},
                 'ntpv3': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'server': {'v_range': [['6.0.0', '6.2.5'], ['6.2.7', '6.4.1'], ['6.4.3', '']], 'type': 'str'},
-                'interface': {'v_range': [['6.2.7', '6.2.12'], ['6.4.3', '7.0.2'], ['7.4.3', '']], 'type': 'str'},
+                'interface': {'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '7.0.2'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'},
                 'interface-select-method': {
-                    'v_range': [['6.2.7', '6.2.12'], ['6.4.3', '7.0.2'], ['7.4.3', '']],
+                    'v_range': [['6.2.7', '6.2.13'], ['6.4.3', '7.0.2'], ['7.2.6', '7.2.9'], ['7.4.3', '']],
                     'choices': ['auto', 'sdwan', 'specify'],
                     'type': 'str'
                 },
                 'ip-type': {'v_range': [['7.4.2', '']], 'choices': ['IPv6', 'IPv4', 'Both'], 'type': 'str'},
-                'key-type': {'v_range': [['7.4.3', '']], 'choices': ['SHA1', 'SHA256', 'MD5'], 'type': 'str'}
+                'key-type': {'v_range': [['7.4.3', '']], 'choices': ['SHA1', 'SHA256', 'MD5'], 'type': 'str'},
+                'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -270,9 +272,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
