@@ -103,9 +103,10 @@ options:
                     id:
                         type: int
                         description: ID.
-                    ignore-case:
+                    ignore_case:
+                        aliases: ['ignore-case']
                         type: str
-                        description: Deprecated, please rename it to ignore_case. Enable/disable ignore case.
+                        description: Enable/disable ignore case.
                         choices:
                             - 'disable'
                             - 'enable'
@@ -127,9 +128,10 @@ options:
                     type:
                         type: str
                         description: Pattern type to match.
-            match-type:
+            match_type:
+                aliases: ['match-type']
                 type: str
-                description: Deprecated, please rename it to match_type. Logical relation between entries
+                description: Logical relation between entries
                 choices:
                     - 'match-all'
                     - 'match-any'
@@ -140,15 +142,17 @@ options:
             uuid:
                 type: str
                 description: Universally Unique Identifier
-            match-around:
+            match_around:
+                aliases: ['match-around']
                 type: str
-                description: Deprecated, please rename it to match_around. Enable/disable match-around support.
+                description: Enable/disable match-around support.
                 choices:
                     - 'disable'
                     - 'enable'
-            fgd-id:
+            fgd_id:
+                aliases: ['fgd-id']
                 type: int
-                description: Deprecated, please rename it to fgd_id. ID of object in FortiGuard database.
+                description: ID of object in FortiGuard database.
 '''
 
 EXAMPLES = '''
@@ -228,23 +232,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/dlp/dictionary',
         '/pm/config/global/obj/dlp/dictionary'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/dlp/dictionary/{dictionary}',
-        '/pm/config/global/obj/dlp/dictionary/{dictionary}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -274,7 +270,6 @@ def main():
                 'match-around': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'fgd-id': {'v_range': [['7.6.0', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -288,9 +283,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
