@@ -97,9 +97,10 @@ options:
                 elements: dict
                 description: Entries.
                 suboptions:
-                    file-type:
+                    file_type:
+                        aliases: ['file-type']
                         type: str
-                        description: Deprecated, please rename it to file_type. Select a file type.
+                        description: Select a file type.
                         choices:
                             - 'unknown'
                             - 'ignored'
@@ -170,9 +171,11 @@ options:
                             - 'lzip'
                             - 'wasm'
                             - 'sylk'
-                    filter-type:
+                            - 'shellscript'
+                    filter_type:
+                        aliases: ['filter-type']
                         type: str
-                        description: Deprecated, please rename it to filter_type. Filter by file name pattern or by file type.
+                        description: Filter by file name pattern or by file type.
                         choices:
                             - 'pattern'
                             - 'type'
@@ -258,23 +261,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/dlp/filepattern',
         '/pm/config/global/obj/dlp/filepattern'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/dlp/filepattern/{filepattern}',
-        '/pm/config/global/obj/dlp/filepattern/{filepattern}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -293,7 +288,7 @@ def main():
                                 'zip', 'cab', 'bzip2', 'bzip', 'activemime', 'mime', 'hlp', 'arj', 'base64', 'binhex', 'uue', 'fsg', 'aspack', 'msc',
                                 'petite', 'jpeg', 'gif', 'tiff', 'png', 'bmp', 'msi', 'mpeg', 'mov', 'mp3', 'wma', 'wav', 'pdf', 'avi', 'rm', 'torrent',
                                 'hibun', '7z', 'xz', 'msofficex', 'mach-o', 'dmg', '.net', 'xar', 'chm', 'iso', 'crx', 'sis', 'prc', 'class', 'jad',
-                                'cod', 'flac', 'registry', 'hwp', 'rpm', 'c/cpp', 'pfile', 'lzip', 'wasm', 'sylk'
+                                'cod', 'flac', 'registry', 'hwp', 'rpm', 'c/cpp', 'pfile', 'lzip', 'wasm', 'sylk', 'shellscript'
                             ],
                             'type': 'str'
                         },
@@ -305,7 +300,6 @@ def main():
                 'id': {'required': True, 'type': 'int'},
                 'name': {'type': 'str'}
             }
-
         }
     }
 
@@ -319,9 +313,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
