@@ -93,9 +93,10 @@ options:
         required: false
         type: dict
         suboptions:
-            addr-type:
+            addr_type:
+                aliases: ['addr-type']
                 type: str
-                description: Deprecated, please rename it to addr_type. Type of address.
+                description: Type of address.
                 choices:
                     - 'ipv4'
                     - 'ipv6'
@@ -103,12 +104,14 @@ options:
                 type: int
                 description: Trusted IP entry ID.
                 required: true
-            ip4-subnet:
+            ip4_subnet:
+                aliases: ['ip4-subnet']
                 type: str
-                description: Deprecated, please rename it to ip4_subnet. IPv4 network address or network address/subnet mask bits.
-            ip6-subnet:
+                description: IPv4 network address or network address/subnet mask bits.
+            ip6_subnet:
+                aliases: ['ip6-subnet']
                 type: str
-                description: Deprecated, please rename it to ip6_subnet. IPv6 network address/subnet mask bits.
+                description: IPv6 network address/subnet mask bits.
             status:
                 type: str
                 description: Enable/disable status.
@@ -185,23 +188,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/emailfilter/iptrust/{iptrust}/entries',
         '/pm/config/global/obj/emailfilter/iptrust/{iptrust}/entries'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/emailfilter/iptrust/{iptrust}/entries/{entries}',
-        '/pm/config/global/obj/emailfilter/iptrust/{iptrust}/entries/{entries}'
-    ]
-
     url_params = ['adom', 'iptrust']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -217,7 +212,6 @@ def main():
                 'ip6-subnet': {'v_range': [['6.2.0', '']], 'type': 'str'},
                 'status': {'v_range': [['6.2.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -231,9 +225,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
