@@ -99,16 +99,18 @@ options:
         required: false
         type: dict
         suboptions:
-            end-port:
+            end_port:
+                aliases: ['end-port']
                 type: int
-                description: Deprecated, please rename it to end_port. Integer value for ending TCP/UDP/SCTP destination port in range
+                description: Integer value for ending TCP/UDP/SCTP destination port in range
             id:
                 type: int
                 description: Custom entry port range ID.
                 required: true
-            start-port:
+            start_port:
+                aliases: ['start-port']
                 type: int
-                description: Deprecated, please rename it to start_port. Integer value for starting TCP/UDP/SCTP destination port in range
+                description: Integer value for starting TCP/UDP/SCTP destination port in range
 '''
 
 EXAMPLES = '''
@@ -178,23 +180,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/internet-service-addition/{internet-service-addition}/entry/{entry}/port-range',
         '/pm/config/global/obj/firewall/internet-service-addition/{internet-service-addition}/entry/{entry}/port-range'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/internet-service-addition/{internet-service-addition}/entry/{entry}/port-range/{port-range}',
-        '/pm/config/global/obj/firewall/internet-service-addition/{internet-service-addition}/entry/{entry}/port-range/{port-range}'
-    ]
-
     url_params = ['adom', 'internet-service-addition', 'entry']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -210,7 +204,6 @@ def main():
                 'id': {'v_range': [['6.2.2', '']], 'required': True, 'type': 'int'},
                 'start-port': {'v_range': [['6.2.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -224,9 +217,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
