@@ -86,9 +86,10 @@ options:
         required: false
         type: dict
         suboptions:
-            inspect-all:
+            inspect_all:
+                aliases: ['inspect-all']
                 type: str
-                description: Deprecated, please rename it to inspect_all. Enable/disable the inspection of all ports for the protocol.
+                description: Enable/disable the inspection of all ports for the protocol.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -101,21 +102,24 @@ options:
                     - 'fragmail'
                     - 'no-content-summary'
                     - 'splice'
-            oversize-limit:
+            oversize_limit:
+                aliases: ['oversize-limit']
                 type: int
-                description: Deprecated, please rename it to oversize_limit. Maximum in-memory file size that can be scanned
+                description: Maximum in-memory file size that can be scanned
             ports:
                 type: raw
                 description: (list) Ports to scan for content
-            scan-bzip2:
+            scan_bzip2:
+                aliases: ['scan-bzip2']
                 type: str
-                description: Deprecated, please rename it to scan_bzip2. Enable/disable scanning of BZip2 compressed files.
+                description: Enable/disable scanning of BZip2 compressed files.
                 choices:
                     - 'disable'
                     - 'enable'
-            server-busy:
+            server_busy:
+                aliases: ['server-busy']
                 type: str
-                description: Deprecated, please rename it to server_busy. Enable/disable SMTP server busy when server not available.
+                description: Enable/disable SMTP server busy when server not available.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -125,21 +129,25 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            uncompressed-nest-limit:
+            uncompressed_nest_limit:
+                aliases: ['uncompressed-nest-limit']
                 type: int
-                description: Deprecated, please rename it to uncompressed_nest_limit. Maximum nested levels of compression that can be uncompressed and...
-            uncompressed-oversize-limit:
+                description: Maximum nested levels of compression that can be uncompressed and scanned
+            uncompressed_oversize_limit:
+                aliases: ['uncompressed-oversize-limit']
                 type: int
-                description: Deprecated, please rename it to uncompressed_oversize_limit. Maximum in-memory uncompressed file size that can be scanned
-            ssl-offloaded:
+                description: Maximum in-memory uncompressed file size that can be scanned
+            ssl_offloaded:
+                aliases: ['ssl-offloaded']
                 type: str
-                description: Deprecated, please rename it to ssl_offloaded. SSL decryption and encryption performed by an external device.
+                description: SSL decryption and encryption performed by an external device.
                 choices:
                     - 'no'
                     - 'yes'
-            proxy-after-tcp-handshake:
+            proxy_after_tcp_handshake:
+                aliases: ['proxy-after-tcp-handshake']
                 type: str
-                description: Deprecated, please rename it to proxy_after_tcp_handshake. Proxy traffic after the TCP 3-way handshake has been established
+                description: Proxy traffic after the TCP 3-way handshake has been established
                 choices:
                     - 'disable'
                     - 'enable'
@@ -166,10 +174,10 @@ EXAMPLES = '''
         firewall_profileprotocoloptions_smtp:
           inspect_all: <value in [disable, enable]>
           options:
-            - oversize
-            - fragmail
-            - no-content-summary
-            - splice
+            - "oversize"
+            - "fragmail"
+            - "no-content-summary"
+            - "splice"
           oversize_limit: <integer>
           ports: <list or integer>
           scan_bzip2: <value in [disable, enable]>
@@ -222,23 +230,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/profile-protocol-options/{profile-protocol-options}/smtp',
         '/pm/config/global/obj/firewall/profile-protocol-options/{profile-protocol-options}/smtp'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/profile-protocol-options/{profile-protocol-options}/smtp/{smtp}',
-        '/pm/config/global/obj/firewall/profile-protocol-options/{profile-protocol-options}/smtp/{smtp}'
-    ]
-
     url_params = ['adom', 'profile-protocol-options']
     module_primary_key = None
     module_arg_spec = {
@@ -261,7 +261,6 @@ def main():
                 'ssl-offloaded': {'v_range': [['6.2.2', '']], 'choices': ['no', 'yes'], 'type': 'str'},
                 'proxy-after-tcp-handshake': {'v_range': [['6.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -275,9 +274,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
