@@ -89,9 +89,10 @@ options:
         required: false
         type: dict
         suboptions:
-            case-sensitivity:
+            case_sensitivity:
+                aliases: ['case-sensitivity']
                 type: str
-                description: Deprecated, please rename it to case_sensitivity. Enable to make the pattern case sensitive.
+                description: Enable to make the pattern case sensitive.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -107,35 +108,40 @@ options:
             header:
                 type: str
                 description: HTTP header name as a regular expression.
-            header-group:
+            header_group:
+                aliases: ['header-group']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to header_group. Header group.
+                description: Header group.
                 suboptions:
-                    case-sensitivity:
+                    case_sensitivity:
+                        aliases: ['case-sensitivity']
                         type: str
-                        description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
+                        description: Case sensitivity in pattern.
                         choices:
                             - 'disable'
                             - 'enable'
                     header:
                         type: str
                         description: HTTP header regular expression.
-                    header-name:
+                    header_name:
+                        aliases: ['header-name']
                         type: str
-                        description: Deprecated, please rename it to header_name. HTTP header.
+                        description: HTTP header.
                     id:
                         type: int
                         description: ID.
-            header-name:
+            header_name:
+                aliases: ['header-name']
                 type: str
-                description: Deprecated, please rename it to header_name. Name of HTTP header.
+                description: Name of HTTP header.
             host:
                 type: str
                 description: Address object for the host.
-            host-regex:
+            host_regex:
+                aliases: ['host-regex']
                 type: str
-                description: Deprecated, please rename it to host_regex. Host name as a regular expression.
+                description: Host name as a regular expression.
             method:
                 type: list
                 elements: str
@@ -149,6 +155,9 @@ options:
                     - 'put'
                     - 'trace'
                     - 'connect'
+                    - 'other'
+                    - 'patch'
+                    - 'update'
             name:
                 type: str
                 description: Address name.
@@ -217,18 +226,21 @@ options:
             tags:
                 type: str
                 description: Names of object-tags
-            _image-base64:
+            _image_base64:
+                aliases: ['_image-base64']
                 type: str
-                description: Deprecated, please rename it to _image_base64. Image base64.
+                description: Image base64.
             application:
                 type: raw
                 description: (list) SaaS application.
-            ua-max-ver:
+            ua_max_ver:
+                aliases: ['ua-max-ver']
                 type: str
-                description: Deprecated, please rename it to ua_max_ver. Maximum version of the user agent specified in dotted notation.
-            ua-min-ver:
+                description: Maximum version of the user agent specified in dotted notation.
+            ua_min_ver:
+                aliases: ['ua-min-ver']
                 type: str
-                description: Deprecated, please rename it to ua_min_ver. Minimum version of the user agent specified in dotted notation.
+                description: Minimum version of the user agent specified in dotted notation.
 '''
 
 EXAMPLES = '''
@@ -310,23 +322,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/proxy-address',
         '/pm/config/global/obj/firewall/proxy-address'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/proxy-address/{proxy-address}',
-        '/pm/config/global/obj/firewall/proxy-address/{proxy-address}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -353,7 +357,11 @@ def main():
                 'header-name': {'type': 'str'},
                 'host': {'type': 'str'},
                 'host-regex': {'type': 'str'},
-                'method': {'type': 'list', 'choices': ['delete', 'get', 'head', 'options', 'post', 'put', 'trace', 'connect'], 'elements': 'str'},
+                'method': {
+                    'type': 'list',
+                    'choices': ['delete', 'get', 'head', 'options', 'post', 'put', 'trace', 'connect', 'other', 'patch', 'update'],
+                    'elements': 'str'
+                },
                 'name': {'required': True, 'type': 'str'},
                 'path': {'type': 'str'},
                 'query': {'type': 'str'},
@@ -370,13 +378,12 @@ def main():
                 'ua': {'type': 'list', 'choices': ['chrome', 'ms', 'firefox', 'safari', 'other', 'ie', 'edge'], 'elements': 'str'},
                 'uuid': {'type': 'str'},
                 'visibility': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'tags': {'v_range': [['6.2.0', '6.4.14']], 'type': 'str'},
+                'tags': {'v_range': [['6.2.0', '6.4.15']], 'type': 'str'},
                 '_image-base64': {'v_range': [['6.2.2', '']], 'type': 'str'},
                 'application': {'v_range': [['7.2.1', '']], 'type': 'raw'},
                 'ua-max-ver': {'v_range': [['7.2.2', '']], 'type': 'str'},
                 'ua-min-ver': {'v_range': [['7.2.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -390,9 +397,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
