@@ -211,11 +211,11 @@ EXAMPLES = '''
           cipher: <value in [TLS-RSA-WITH-RC4-128-MD5, TLS-RSA-WITH-RC4-128-SHA, TLS-RSA-WITH-DES-CBC-SHA, ...]>
           priority: <integer>
           versions:
-            - ssl-3.0
-            - tls-1.0
-            - tls-1.1
-            - tls-1.2
-            - tls-1.3
+            - "ssl-3.0"
+            - "tls-1.0"
+            - "tls-1.1"
+            - "tls-1.2"
+            - "tls-1.3"
 '''
 
 RETURN = '''
@@ -259,23 +259,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}/ssl-cipher-suites',
         '/pm/config/global/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}/ssl-cipher-suites'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}/ssl-cipher-suites/{ssl-cipher-suites}',
-        '/pm/config/global/obj/firewall/vip6/{vip6}/dynamic_mapping/{dynamic_mapping}/ssl-cipher-suites/{ssl-cipher-suites}'
-    ]
-
     url_params = ['adom', 'vip6', 'dynamic_mapping']
     module_primary_key = None
     module_arg_spec = {
@@ -284,10 +276,10 @@ def main():
         'dynamic_mapping': {'required': True, 'type': 'str'},
         'firewall_vip6_dynamicmapping_sslciphersuites': {
             'type': 'dict',
-            'v_range': [['7.0.2', '7.4.0']],
+            'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']],
             'options': {
                 'cipher': {
-                    'v_range': [['7.0.2', '7.4.0']],
+                    'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']],
                     'choices': [
                         'TLS-RSA-WITH-RC4-128-MD5', 'TLS-RSA-WITH-RC4-128-SHA', 'TLS-RSA-WITH-DES-CBC-SHA', 'TLS-RSA-WITH-3DES-EDE-CBC-SHA',
                         'TLS-RSA-WITH-AES-128-CBC-SHA', 'TLS-RSA-WITH-AES-256-CBC-SHA', 'TLS-RSA-WITH-AES-128-CBC-SHA256',
@@ -316,15 +308,14 @@ def main():
                     ],
                     'type': 'str'
                 },
-                'priority': {'v_range': [['7.0.2', '7.4.0']], 'type': 'int'},
+                'priority': {'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
                 'versions': {
-                    'v_range': [['7.0.2', '7.4.0']],
+                    'v_range': [['7.0.2', '7.2.5'], ['7.4.0', '7.4.0']],
                     'type': 'list',
                     'choices': ['ssl-3.0', 'tls-1.0', 'tls-1.1', 'tls-1.2', 'tls-1.3'],
                     'elements': 'str'
                 }
             }
-
         }
     }
 
@@ -338,9 +329,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
