@@ -97,15 +97,17 @@ options:
         required: false
         type: dict
         suboptions:
-            accept-mode:
+            accept_mode:
+                aliases: ['accept-mode']
                 type: str
-                description: Deprecated, please rename it to accept_mode. Accept mode.
+                description: Accept mode.
                 choices:
                     - 'disable'
                     - 'enable'
-            adv-interval:
+            adv_interval:
+                aliases: ['adv-interval']
                 type: int
-                description: Deprecated, please rename it to adv_interval. Adv interval.
+                description: Adv interval.
             preempt:
                 type: str
                 description: Preempt.
@@ -115,9 +117,10 @@ options:
             priority:
                 type: int
                 description: Priority.
-            start-time:
+            start_time:
+                aliases: ['start-time']
                 type: int
-                description: Deprecated, please rename it to start_time. Start time.
+                description: Start time.
             status:
                 type: str
                 description: Status.
@@ -212,23 +215,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/fsp/vlan/{vlan}/dynamic_mapping/{dynamic_mapping}/interface/ipv6/vrrp6',
         '/pm/config/global/obj/fsp/vlan/{vlan}/dynamic_mapping/{dynamic_mapping}/interface/ipv6/vrrp6'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/fsp/vlan/{vlan}/dynamic_mapping/{dynamic_mapping}/interface/ipv6/vrrp6/{vrrp6}',
-        '/pm/config/global/obj/fsp/vlan/{vlan}/dynamic_mapping/{dynamic_mapping}/interface/ipv6/vrrp6/{vrrp6}'
-    ]
-
     url_params = ['adom', 'vlan', 'dynamic_mapping']
     module_primary_key = None
     module_arg_spec = {
@@ -237,20 +232,19 @@ def main():
         'dynamic_mapping': {'required': True, 'type': 'str'},
         'fsp_vlan_dynamicmapping_interface_ipv6_vrrp6': {
             'type': 'dict',
-            'v_range': [['6.2.2', '7.4.0']],
+            'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']],
             'options': {
-                'accept-mode': {'v_range': [['6.2.2', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'adv-interval': {'v_range': [['6.2.2', '7.4.0']], 'type': 'int'},
-                'preempt': {'v_range': [['6.2.2', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'priority': {'v_range': [['6.2.2', '7.4.0']], 'type': 'int'},
-                'start-time': {'v_range': [['6.2.2', '7.4.0']], 'type': 'int'},
-                'status': {'v_range': [['6.2.2', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'vrdst6': {'v_range': [['6.2.2', '7.4.0']], 'type': 'str'},
-                'vrgrp': {'v_range': [['6.2.2', '7.4.0']], 'type': 'int'},
-                'vrid': {'v_range': [['6.2.2', '7.4.0']], 'type': 'int'},
-                'vrip6': {'v_range': [['6.2.2', '7.4.0']], 'type': 'str'}
+                'accept-mode': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'adv-interval': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
+                'preempt': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'priority': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
+                'start-time': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
+                'status': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'vrdst6': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'str'},
+                'vrgrp': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
+                'vrid': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'int'},
+                'vrip6': {'v_range': [['6.2.2', '7.2.5'], ['7.4.0', '7.4.0']], 'type': 'str'}
             }
-
         }
     }
 
@@ -264,9 +258,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
