@@ -86,62 +86,73 @@ options:
         suboptions:
             autoconf:
                 type: str
-                description: No description.
+                description: Autoconf.
                 choices:
                     - 'disable'
                     - 'enable'
-            dhcp6-client-options:
+            dhcp6_client_options:
+                aliases: ['dhcp6-client-options']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to dhcp6_client_options.
+                description: Dhcp6 client options.
                 choices:
                     - 'rapid'
                     - 'iapd'
                     - 'iana'
                     - 'dns'
                     - 'dnsname'
-            dhcp6-information-request:
+            dhcp6_information_request:
+                aliases: ['dhcp6-information-request']
                 type: str
-                description: Deprecated, please rename it to dhcp6_information_request.
+                description: Dhcp6 information request.
                 choices:
                     - 'disable'
                     - 'enable'
-            dhcp6-prefix-delegation:
+            dhcp6_prefix_delegation:
+                aliases: ['dhcp6-prefix-delegation']
                 type: str
-                description: Deprecated, please rename it to dhcp6_prefix_delegation.
+                description: Dhcp6 prefix delegation.
                 choices:
                     - 'disable'
                     - 'enable'
-            dhcp6-prefix-hint:
+            dhcp6_prefix_hint:
+                aliases: ['dhcp6-prefix-hint']
                 type: str
-                description: Deprecated, please rename it to dhcp6_prefix_hint.
-            dhcp6-prefix-hint-plt:
+                description: Dhcp6 prefix hint.
+            dhcp6_prefix_hint_plt:
+                aliases: ['dhcp6-prefix-hint-plt']
                 type: int
-                description: Deprecated, please rename it to dhcp6_prefix_hint_plt.
-            dhcp6-prefix-hint-vlt:
+                description: Dhcp6 prefix hint plt.
+            dhcp6_prefix_hint_vlt:
+                aliases: ['dhcp6-prefix-hint-vlt']
                 type: int
-                description: Deprecated, please rename it to dhcp6_prefix_hint_vlt.
-            dhcp6-relay-ip:
+                description: Dhcp6 prefix hint vlt.
+            dhcp6_relay_ip:
+                aliases: ['dhcp6-relay-ip']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_ip.
-            dhcp6-relay-service:
+                description: Dhcp6 relay ip.
+            dhcp6_relay_service:
+                aliases: ['dhcp6-relay-service']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_service.
+                description: Dhcp6 relay service.
                 choices:
                     - 'disable'
                     - 'enable'
-            dhcp6-relay-type:
+            dhcp6_relay_type:
+                aliases: ['dhcp6-relay-type']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_type.
+                description: Dhcp6 relay type.
                 choices:
                     - 'regular'
-            ip6-address:
+            ip6_address:
+                aliases: ['ip6-address']
                 type: str
-                description: Deprecated, please rename it to ip6_address.
-            ip6-allowaccess:
+                description: Ip6 address.
+            ip6_allowaccess:
+                aliases: ['ip6-allowaccess']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ip6_allowaccess.
+                description: Ip6 allowaccess.
                 choices:
                     - 'https'
                     - 'ping'
@@ -152,269 +163,336 @@ options:
                     - 'fgfm'
                     - 'capwap'
                     - 'fabric'
-            ip6-default-life:
+            ip6_default_life:
+                aliases: ['ip6-default-life']
                 type: int
-                description: Deprecated, please rename it to ip6_default_life.
-            ip6-dns-server-override:
+                description: Ip6 default life.
+            ip6_dns_server_override:
+                aliases: ['ip6-dns-server-override']
                 type: str
-                description: Deprecated, please rename it to ip6_dns_server_override.
+                description: Ip6 dns server override.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-hop-limit:
+            ip6_hop_limit:
+                aliases: ['ip6-hop-limit']
                 type: int
-                description: Deprecated, please rename it to ip6_hop_limit.
-            ip6-link-mtu:
+                description: Ip6 hop limit.
+            ip6_link_mtu:
+                aliases: ['ip6-link-mtu']
                 type: int
-                description: Deprecated, please rename it to ip6_link_mtu.
-            ip6-manage-flag:
+                description: Ip6 link mtu.
+            ip6_manage_flag:
+                aliases: ['ip6-manage-flag']
                 type: str
-                description: Deprecated, please rename it to ip6_manage_flag.
+                description: Ip6 manage flag.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-max-interval:
+            ip6_max_interval:
+                aliases: ['ip6-max-interval']
                 type: int
-                description: Deprecated, please rename it to ip6_max_interval.
-            ip6-min-interval:
+                description: Ip6 max interval.
+            ip6_min_interval:
+                aliases: ['ip6-min-interval']
                 type: int
-                description: Deprecated, please rename it to ip6_min_interval.
-            ip6-mode:
+                description: Ip6 min interval.
+            ip6_mode:
+                aliases: ['ip6-mode']
                 type: str
-                description: Deprecated, please rename it to ip6_mode.
+                description: Ip6 mode.
                 choices:
                     - 'static'
                     - 'dhcp'
                     - 'pppoe'
                     - 'delegated'
-            ip6-other-flag:
+            ip6_other_flag:
+                aliases: ['ip6-other-flag']
                 type: str
-                description: Deprecated, please rename it to ip6_other_flag.
+                description: Ip6 other flag.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-reachable-time:
+            ip6_reachable_time:
+                aliases: ['ip6-reachable-time']
                 type: int
-                description: Deprecated, please rename it to ip6_reachable_time.
-            ip6-retrans-time:
+                description: Ip6 reachable time.
+            ip6_retrans_time:
+                aliases: ['ip6-retrans-time']
                 type: int
-                description: Deprecated, please rename it to ip6_retrans_time.
-            ip6-send-adv:
+                description: Ip6 retrans time.
+            ip6_send_adv:
+                aliases: ['ip6-send-adv']
                 type: str
-                description: Deprecated, please rename it to ip6_send_adv.
+                description: Ip6 send adv.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-subnet:
+            ip6_subnet:
+                aliases: ['ip6-subnet']
                 type: str
-                description: Deprecated, please rename it to ip6_subnet.
-            ip6-upstream-interface:
+                description: Ip6 subnet.
+            ip6_upstream_interface:
+                aliases: ['ip6-upstream-interface']
                 type: str
-                description: Deprecated, please rename it to ip6_upstream_interface.
-            nd-cert:
+                description: Ip6 upstream interface.
+            nd_cert:
+                aliases: ['nd-cert']
                 type: str
-                description: Deprecated, please rename it to nd_cert.
-            nd-cga-modifier:
+                description: Nd cert.
+            nd_cga_modifier:
+                aliases: ['nd-cga-modifier']
                 type: str
-                description: Deprecated, please rename it to nd_cga_modifier.
-            nd-mode:
+                description: Nd cga modifier.
+            nd_mode:
+                aliases: ['nd-mode']
                 type: str
-                description: Deprecated, please rename it to nd_mode.
+                description: Nd mode.
                 choices:
                     - 'basic'
                     - 'SEND-compatible'
-            nd-security-level:
+            nd_security_level:
+                aliases: ['nd-security-level']
                 type: int
-                description: Deprecated, please rename it to nd_security_level.
-            nd-timestamp-delta:
+                description: Nd security level.
+            nd_timestamp_delta:
+                aliases: ['nd-timestamp-delta']
                 type: int
-                description: Deprecated, please rename it to nd_timestamp_delta.
-            nd-timestamp-fuzz:
+                description: Nd timestamp delta.
+            nd_timestamp_fuzz:
+                aliases: ['nd-timestamp-fuzz']
                 type: int
-                description: Deprecated, please rename it to nd_timestamp_fuzz.
+                description: Nd timestamp fuzz.
             vrip6_link_local:
                 type: str
-                description: No description.
-            vrrp-virtual-mac6:
+                description: Vrip6 link local.
+            vrrp_virtual_mac6:
+                aliases: ['vrrp-virtual-mac6']
                 type: str
-                description: Deprecated, please rename it to vrrp_virtual_mac6.
+                description: Vrrp virtual mac6.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-delegated-prefix-list:
+            ip6_delegated_prefix_list:
+                aliases: ['ip6-delegated-prefix-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip6_delegated_prefix_list.
+                description: Ip6 delegated prefix list.
                 suboptions:
-                    autonomous-flag:
+                    autonomous_flag:
+                        aliases: ['autonomous-flag']
                         type: str
-                        description: Deprecated, please rename it to autonomous_flag.
+                        description: Autonomous flag.
                         choices:
                             - 'disable'
                             - 'enable'
-                    onlink-flag:
+                    onlink_flag:
+                        aliases: ['onlink-flag']
                         type: str
-                        description: Deprecated, please rename it to onlink_flag.
+                        description: Onlink flag.
                         choices:
                             - 'disable'
                             - 'enable'
-                    prefix-id:
+                    prefix_id:
+                        aliases: ['prefix-id']
                         type: int
-                        description: Deprecated, please rename it to prefix_id.
+                        description: Prefix id.
                     rdnss:
                         type: raw
-                        description: (list) No description.
-                    rdnss-service:
+                        description: (list) Rdnss.
+                    rdnss_service:
+                        aliases: ['rdnss-service']
                         type: str
-                        description: Deprecated, please rename it to rdnss_service.
+                        description: Rdnss service.
                         choices:
                             - 'delegated'
                             - 'default'
                             - 'specify'
                     subnet:
                         type: str
-                        description: No description.
-                    upstream-interface:
+                        description: Subnet.
+                    upstream_interface:
+                        aliases: ['upstream-interface']
                         type: str
-                        description: Deprecated, please rename it to upstream_interface.
-                    delegated-prefix-iaid:
+                        description: Upstream interface.
+                    delegated_prefix_iaid:
+                        aliases: ['delegated-prefix-iaid']
                         type: int
-                        description: Deprecated, please rename it to delegated_prefix_iaid. IAID of obtained delegated-prefix from the upstream interface.
-            ip6-extra-addr:
+                        description: IAID of obtained delegated-prefix from the upstream interface.
+            ip6_extra_addr:
+                aliases: ['ip6-extra-addr']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip6_extra_addr.
+                description: Ip6 extra addr.
                 suboptions:
                     prefix:
                         type: str
-                        description: No description.
-            ip6-prefix-list:
+                        description: Prefix.
+            ip6_prefix_list:
+                aliases: ['ip6-prefix-list']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip6_prefix_list.
+                description: Ip6 prefix list.
                 suboptions:
-                    autonomous-flag:
+                    autonomous_flag:
+                        aliases: ['autonomous-flag']
                         type: str
-                        description: Deprecated, please rename it to autonomous_flag.
+                        description: Autonomous flag.
                         choices:
                             - 'disable'
                             - 'enable'
                     dnssl:
                         type: raw
-                        description: (list) No description.
-                    onlink-flag:
+                        description: (list) Dnssl.
+                    onlink_flag:
+                        aliases: ['onlink-flag']
                         type: str
-                        description: Deprecated, please rename it to onlink_flag.
+                        description: Onlink flag.
                         choices:
                             - 'disable'
                             - 'enable'
-                    preferred-life-time:
+                    preferred_life_time:
+                        aliases: ['preferred-life-time']
                         type: int
-                        description: Deprecated, please rename it to preferred_life_time.
+                        description: Preferred life time.
                     prefix:
                         type: str
-                        description: No description.
+                        description: Prefix.
                     rdnss:
                         type: raw
-                        description: (list) No description.
-                    valid-life-time:
+                        description: (list) Rdnss.
+                    valid_life_time:
+                        aliases: ['valid-life-time']
                         type: int
-                        description: Deprecated, please rename it to valid_life_time.
+                        description: Valid life time.
             vrrp6:
                 type: list
                 elements: dict
-                description: No description.
+                description: Vrrp6.
                 suboptions:
-                    accept-mode:
+                    accept_mode:
+                        aliases: ['accept-mode']
                         type: str
-                        description: Deprecated, please rename it to accept_mode.
+                        description: Accept mode.
                         choices:
                             - 'disable'
                             - 'enable'
-                    adv-interval:
+                    adv_interval:
+                        aliases: ['adv-interval']
                         type: int
-                        description: Deprecated, please rename it to adv_interval.
+                        description: Adv interval.
                     preempt:
                         type: str
-                        description: No description.
+                        description: Preempt.
                         choices:
                             - 'disable'
                             - 'enable'
                     priority:
                         type: int
-                        description: No description.
-                    start-time:
+                        description: Priority.
+                    start_time:
+                        aliases: ['start-time']
                         type: int
-                        description: Deprecated, please rename it to start_time.
+                        description: Start time.
                     status:
                         type: str
-                        description: No description.
+                        description: Status.
                         choices:
                             - 'disable'
                             - 'enable'
                     vrdst6:
                         type: str
-                        description: No description.
+                        description: Vrdst6.
                     vrgrp:
                         type: int
-                        description: No description.
+                        description: Vrgrp.
                     vrid:
                         type: int
-                        description: No description.
+                        description: Vrid.
                     vrip6:
                         type: str
-                        description: No description.
-                    ignore-default-route:
+                        description: Vrip6.
+                    ignore_default_route:
+                        aliases: ['ignore-default-route']
                         type: str
-                        description: Deprecated, please rename it to ignore_default_route. Enable/disable ignoring of default route when checking desti...
+                        description: Enable/disable ignoring of default route when checking destination.
                         choices:
                             - 'disable'
                             - 'enable'
-            interface-identifier:
+                    vrdst_priority:
+                        aliases: ['vrdst-priority']
+                        type: int
+                        description: Priority of the virtual router when the virtual router destination becomes unreachable
+            interface_identifier:
+                aliases: ['interface-identifier']
                 type: str
-                description: Deprecated, please rename it to interface_identifier.
-            unique-autoconf-addr:
+                description: Interface identifier.
+            unique_autoconf_addr:
+                aliases: ['unique-autoconf-addr']
                 type: str
-                description: Deprecated, please rename it to unique_autoconf_addr.
+                description: Unique autoconf addr.
                 choices:
                     - 'disable'
                     - 'enable'
-            icmp6-send-redirect:
+            icmp6_send_redirect:
+                aliases: ['icmp6-send-redirect']
                 type: str
-                description: Deprecated, please rename it to icmp6_send_redirect. Enable/disable sending of ICMPv6 redirects.
+                description: Enable/disable sending of ICMPv6 redirects.
                 choices:
                     - 'disable'
                     - 'enable'
-            cli-conn6-status:
+            cli_conn6_status:
+                aliases: ['cli-conn6-status']
                 type: int
-                description: Deprecated, please rename it to cli_conn6_status.
-            ip6-prefix-mode:
+                description: Cli conn6 status.
+            ip6_prefix_mode:
+                aliases: ['ip6-prefix-mode']
                 type: str
-                description: Deprecated, please rename it to ip6_prefix_mode. Assigning a prefix from DHCP or RA.
+                description: Assigning a prefix from DHCP or RA.
                 choices:
                     - 'dhcp6'
                     - 'ra'
-            ra-send-mtu:
+            ra_send_mtu:
+                aliases: ['ra-send-mtu']
                 type: str
-                description: Deprecated, please rename it to ra_send_mtu. Enable/disable sending link MTU in RA packet.
+                description: Enable/disable sending link MTU in RA packet.
                 choices:
                     - 'disable'
                     - 'enable'
-            ip6-delegated-prefix-iaid:
+            ip6_delegated_prefix_iaid:
+                aliases: ['ip6-delegated-prefix-iaid']
                 type: int
-                description: Deprecated, please rename it to ip6_delegated_prefix_iaid. IAID of obtained delegated-prefix from the upstream interface.
-            dhcp6-relay-source-interface:
+                description: IAID of obtained delegated-prefix from the upstream interface.
+            dhcp6_relay_source_interface:
+                aliases: ['dhcp6-relay-source-interface']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_source_interface. Enable/disable use of address on this interface as the sourc...
+                description: Enable/disable use of address on this interface as the source address of the relay message.
                 choices:
                     - 'disable'
                     - 'enable'
-            dhcp6-relay-interface-id:
+            dhcp6_relay_interface_id:
+                aliases: ['dhcp6-relay-interface-id']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_interface_id. DHCP6 relay interface ID.
-            dhcp6-relay-source-ip:
+                description: DHCP6 relay interface ID.
+            dhcp6_relay_source_ip:
+                aliases: ['dhcp6-relay-source-ip']
                 type: str
-                description: Deprecated, please rename it to dhcp6_relay_source_ip. IPv6 address used by the DHCP6 relay as its source IP.
+                description: IPv6 address used by the DHCP6 relay as its source IP.
+            ip6_adv_rio:
+                aliases: ['ip6-adv-rio']
+                type: str
+                description: Enable/disable sending advertisements with route information option.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            ip6_route_pref:
+                aliases: ['ip6-route-pref']
+                type: str
+                description: Set route preference to the interface
+                choices:
+                    - 'medium'
+                    - 'high'
+                    - 'low'
 '''
 
 EXAMPLES = '''
@@ -438,11 +516,11 @@ EXAMPLES = '''
         fsp_vlan_interface_ipv6:
           autoconf: <value in [disable, enable]>
           dhcp6_client_options:
-            - rapid
-            - iapd
-            - iana
-            - dns
-            - dnsname
+            - "rapid"
+            - "iapd"
+            - "iana"
+            - "dns"
+            - "dnsname"
           dhcp6_information_request: <value in [disable, enable]>
           dhcp6_prefix_delegation: <value in [disable, enable]>
           dhcp6_prefix_hint: <string>
@@ -453,15 +531,15 @@ EXAMPLES = '''
           dhcp6_relay_type: <value in [regular]>
           ip6_address: <string>
           ip6_allowaccess:
-            - https
-            - ping
-            - ssh
-            - snmp
-            - http
-            - telnet
-            - fgfm
-            - capwap
-            - fabric
+            - "https"
+            - "ping"
+            - "ssh"
+            - "snmp"
+            - "http"
+            - "telnet"
+            - "fgfm"
+            - "capwap"
+            - "fabric"
           ip6_default_life: <integer>
           ip6_dns_server_override: <value in [disable, enable]>
           ip6_hop_limit: <integer>
@@ -519,6 +597,7 @@ EXAMPLES = '''
               vrid: <integer>
               vrip6: <string>
               ignore_default_route: <value in [disable, enable]>
+              vrdst_priority: <integer>
           interface_identifier: <string>
           unique_autoconf_addr: <value in [disable, enable]>
           icmp6_send_redirect: <value in [disable, enable]>
@@ -529,6 +608,8 @@ EXAMPLES = '''
           dhcp6_relay_source_interface: <value in [disable, enable]>
           dhcp6_relay_interface_id: <string>
           dhcp6_relay_source_ip: <string>
+          ip6_adv_rio: <value in [disable, enable]>
+          ip6_route_pref: <value in [medium, high, low]>
 '''
 
 RETURN = '''
@@ -572,23 +653,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/fsp/vlan/{vlan}/interface/ipv6',
         '/pm/config/global/obj/fsp/vlan/{vlan}/interface/ipv6'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/fsp/vlan/{vlan}/interface/ipv6/{ipv6}',
-        '/pm/config/global/obj/fsp/vlan/{vlan}/interface/ipv6/{ipv6}'
-    ]
-
     url_params = ['adom', 'vlan']
     module_primary_key = None
     module_arg_spec = {
@@ -685,7 +758,8 @@ def main():
                         'vrgrp': {'v_range': [['6.2.2', '']], 'type': 'int'},
                         'vrid': {'v_range': [['6.2.2', '']], 'type': 'int'},
                         'vrip6': {'v_range': [['6.2.2', '']], 'type': 'str'},
-                        'ignore-default-route': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'ignore-default-route': {'v_range': [['7.4.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'vrdst-priority': {'v_range': [['7.6.0', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -698,9 +772,10 @@ def main():
                 'ip6-delegated-prefix-iaid': {'v_range': [['7.0.2', '']], 'type': 'int'},
                 'dhcp6-relay-source-interface': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'dhcp6-relay-interface-id': {'v_range': [['7.4.1', '']], 'type': 'str'},
-                'dhcp6-relay-source-ip': {'v_range': [['7.4.1', '']], 'type': 'str'}
+                'dhcp6-relay-source-ip': {'v_range': [['7.4.1', '']], 'type': 'str'},
+                'ip6-adv-rio': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'ip6-route-pref': {'v_range': [['7.6.2', '']], 'choices': ['medium', 'high', 'low'], 'type': 'str'}
             }
-
         }
     }
 
@@ -709,17 +784,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'fsp_vlan_interface_ipv6'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
