@@ -96,14 +96,16 @@ options:
             _policy_block:
                 type: int
                 description: Assigned policy block.
-            access-proxy:
+            access_proxy:
+                aliases: ['access-proxy']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to access_proxy. IPv4 access proxy.
-            access-proxy6:
+                description: IPv4 access proxy.
+            access_proxy6:
+                aliases: ['access-proxy6']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to access_proxy6. IPv6 access proxy.
+                description: IPv6 access proxy.
             action:
                 type: str
                 description: Accept or deny traffic matching the policy parameters.
@@ -111,40 +113,48 @@ options:
                     - 'accept'
                     - 'deny'
                     - 'redirect'
-            application-list:
+                    - 'isolate'
+            application_list:
+                aliases: ['application-list']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to application_list. Name of an existing Application list.
-            av-profile:
+                description: Name of an existing Application list.
+            av_profile:
+                aliases: ['av-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to av_profile. Name of an existing Antivirus profile.
-            block-notification:
+                description: Name of an existing Antivirus profile.
+            block_notification:
+                aliases: ['block-notification']
                 type: str
-                description: Deprecated, please rename it to block_notification. Enable/disable block notification.
+                description: Enable/disable block notification.
                 choices:
                     - 'disable'
                     - 'enable'
-            casb-profile:
+            casb_profile:
+                aliases: ['casb-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to casb_profile. Name of an existing CASB profile.
+                description: Name of an existing CASB profile.
             comments:
                 type: str
                 description: Optional comments.
-            decrypted-traffic-mirror:
+            decrypted_traffic_mirror:
+                aliases: ['decrypted-traffic-mirror']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to decrypted_traffic_mirror. Decrypted traffic mirror.
-            detect-https-in-http-request:
+                description: Decrypted traffic mirror.
+            detect_https_in_http_request:
+                aliases: ['detect-https-in-http-request']
                 type: str
-                description: Deprecated, please rename it to detect_https_in_http_request. Enable/disable detection of HTTPS in HTTP request.
+                description: Enable/disable detection of HTTPS in HTTP request.
                 choices:
                     - 'disable'
                     - 'enable'
-            device-ownership:
+            device_ownership:
+                aliases: ['device-ownership']
                 type: str
-                description: Deprecated, please rename it to device_ownership. When enabled, the ownership enforcement will be done at policy level.
+                description: When enabled, the ownership enforcement will be done at policy level.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -156,21 +166,24 @@ options:
                     - 'domain'
                     - 'policy'
                     - 'user'
-            dlp-profile:
+            dlp_profile:
+                aliases: ['dlp-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to dlp_profile. Name of an existing DLP profile.
-            dnsfilter-profile:
+                description: Name of an existing DLP profile.
+            dnsfilter_profile:
+                aliases: ['dnsfilter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to dnsfilter_profile. Name of an existing DNS filter profile.
+                description: Name of an existing DNS filter profile.
             dstaddr:
                 type: list
                 elements: str
                 description: Destination address objects.
-            dstaddr-negate:
+            dstaddr_negate:
+                aliases: ['dstaddr-negate']
                 type: str
-                description: Deprecated, please rename it to dstaddr_negate. When enabled, destination addresses match against any address EXCEPT the s...
+                description: When enabled, destination addresses match against any address EXCEPT the specified destination addresses.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -182,101 +195,121 @@ options:
                 type: list
                 elements: str
                 description: Destination interface names.
-            emailfilter-profile:
+            emailfilter_profile:
+                aliases: ['emailfilter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to emailfilter_profile. Name of an existing email filter profile.
-            file-filter-profile:
+                description: Name of an existing email filter profile.
+            file_filter_profile:
+                aliases: ['file-filter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to file_filter_profile. Name of an existing file-filter profile.
-            global-label:
+                description: Name of an existing file-filter profile.
+            global_label:
+                aliases: ['global-label']
                 type: str
-                description: Deprecated, please rename it to global_label. Global web-based manager visible label.
+                description: Global web-based manager visible label.
             groups:
                 type: list
                 elements: str
                 description: Names of group objects.
-            http-tunnel-auth:
+            http_tunnel_auth:
+                aliases: ['http-tunnel-auth']
                 type: str
-                description: Deprecated, please rename it to http_tunnel_auth. Enable/disable HTTP tunnel authentication.
+                description: Enable/disable HTTP tunnel authentication.
                 choices:
                     - 'disable'
                     - 'enable'
-            icap-profile:
+            icap_profile:
+                aliases: ['icap-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to icap_profile. Name of an existing ICAP profile.
-            internet-service:
+                description: Name of an existing ICAP profile.
+            internet_service:
+                aliases: ['internet-service']
                 type: str
-                description: Deprecated, please rename it to internet_service. Enable/disable use of Internet Services for this policy.
+                description: Enable/disable use of Internet Services for this policy.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service-custom:
+            internet_service_custom:
+                aliases: ['internet-service-custom']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service_custom. Custom Internet Service name.
-            internet-service-custom-group:
+                description: Custom Internet Service name.
+            internet_service_custom_group:
+                aliases: ['internet-service-custom-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service_custom_group. Custom Internet Service group name.
-            internet-service-group:
+                description: Custom Internet Service group name.
+            internet_service_group:
+                aliases: ['internet-service-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service_group. Internet Service group name.
-            internet-service-name:
+                description: Internet Service group name.
+            internet_service_name:
+                aliases: ['internet-service-name']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service_name. Internet Service name.
-            internet-service-negate:
+                description: Internet Service name.
+            internet_service_negate:
+                aliases: ['internet-service-negate']
                 type: str
-                description: Deprecated, please rename it to internet_service_negate. When enabled, Internet Services match against any internet servic...
+                description: When enabled, Internet Services match against any internet service EXCEPT the selected Internet Service.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service6:
+            internet_service6:
+                aliases: ['internet-service6']
                 type: str
-                description: Deprecated, please rename it to internet_service6. Enable/disable use of Internet Services IPv6 for this policy.
+                description: Enable/disable use of Internet Services IPv6 for this policy.
                 choices:
                     - 'disable'
                     - 'enable'
-            internet-service6-custom:
+            internet_service6_custom:
+                aliases: ['internet-service6-custom']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service6_custom. Custom Internet Service IPv6 name.
-            internet-service6-custom-group:
+                description: Custom Internet Service IPv6 name.
+            internet_service6_custom_group:
+                aliases: ['internet-service6-custom-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service6_custom_group. Custom Internet Service IPv6 group name.
-            internet-service6-group:
+                description: Custom Internet Service IPv6 group name.
+            internet_service6_group:
+                aliases: ['internet-service6-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service6_group. Internet Service IPv6 group name.
-            internet-service6-name:
+                description: Internet Service IPv6 group name.
+            internet_service6_name:
+                aliases: ['internet-service6-name']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service6_name. Internet Service IPv6 name.
-            internet-service6-negate:
+                description: Internet Service IPv6 name.
+            internet_service6_negate:
+                aliases: ['internet-service6-negate']
                 type: str
-                description: Deprecated, please rename it to internet_service6_negate. When enabled, Internet Services match against any internet servi...
+                description: When enabled, Internet Services match against any internet service IPv6 EXCEPT the selected Internet Service IPv6.
                 choices:
                     - 'disable'
                     - 'enable'
-            ips-sensor:
+            ips_sensor:
+                aliases: ['ips-sensor']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ips_sensor. Name of an existing IPS sensor.
-            ips-voip-filter:
+                description: Name of an existing IPS sensor.
+            ips_voip_filter:
+                aliases: ['ips-voip-filter']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ips_voip_filter. Name of an existing VoIP
+                description: Name of an existing VoIP
             label:
                 type: str
                 description: VDOM-specific GUI visible label.
-            log-http-transaction:
+            log_http_transaction:
+                aliases: ['log-http-transaction']
                 type: str
-                description: Deprecated, please rename it to log_http_transaction. Enable/disable HTTP transaction log.
+                description: Enable/disable HTTP transaction log.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -287,9 +320,10 @@ options:
                     - 'disable'
                     - 'all'
                     - 'utm'
-            logtraffic-start:
+            logtraffic_start:
+                aliases: ['logtraffic-start']
                 type: str
-                description: Deprecated, please rename it to logtraffic_start. Enable/disable policy log traffic start.
+                description: Enable/disable policy log traffic start.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -304,17 +338,20 @@ options:
                 type: list
                 elements: str
                 description: Name of IP pool object.
-            profile-group:
+            profile_group:
+                aliases: ['profile-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to profile_group. Name of profile group.
-            profile-protocol-options:
+                description: Name of profile group.
+            profile_protocol_options:
+                aliases: ['profile-protocol-options']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to profile_protocol_options. Name of an existing Protocol options profile.
-            profile-type:
+                description: Name of an existing Protocol options profile.
+            profile_type:
+                aliases: ['profile-type']
                 type: str
-                description: Deprecated, please rename it to profile_type. Determine whether the firewall policy allows security profile groups or sing...
+                description: Determine whether the firewall policy allows security profile groups or single profiles only.
                 choices:
                     - 'single'
                     - 'group'
@@ -330,41 +367,47 @@ options:
                     - 'ssh-tunnel'
                     - 'access-proxy'
                     - 'ztna-proxy'
-            redirect-url:
+            redirect_url:
+                aliases: ['redirect-url']
                 type: str
-                description: Deprecated, please rename it to redirect_url. Redirect URL for further explicit web proxy processing.
-            replacemsg-override-group:
+                description: Redirect URL for further explicit web proxy processing.
+            replacemsg_override_group:
+                aliases: ['replacemsg-override-group']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to replacemsg_override_group. Authentication replacement message override group.
+                description: Authentication replacement message override group.
             schedule:
                 type: list
                 elements: str
                 description: Name of schedule object.
-            sctp-filter-profile:
+            sctp_filter_profile:
+                aliases: ['sctp-filter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to sctp_filter_profile. Name of an existing SCTP filter profile.
+                description: Name of an existing SCTP filter profile.
             service:
                 type: list
                 elements: str
                 description: Name of service objects.
-            service-negate:
+            service_negate:
+                aliases: ['service-negate']
                 type: str
-                description: Deprecated, please rename it to service_negate. When enabled, services match against any service EXCEPT the specified dest...
+                description: When enabled, services match against any service EXCEPT the specified destination services.
                 choices:
                     - 'disable'
                     - 'enable'
-            session-ttl:
+            session_ttl:
+                aliases: ['session-ttl']
                 type: str
-                description: Deprecated, please rename it to session_ttl. TTL in seconds for sessions accepted by this policy
+                description: TTL in seconds for sessions accepted by this policy
             srcaddr:
                 type: list
                 elements: str
                 description: Source address objects.
-            srcaddr-negate:
+            srcaddr_negate:
+                aliases: ['srcaddr-negate']
                 type: str
-                description: Deprecated, please rename it to srcaddr_negate. When enabled, source addresses match against any address EXCEPT the specif...
+                description: When enabled, source addresses match against any address EXCEPT the specified source addresses.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -376,20 +419,23 @@ options:
                 type: list
                 elements: str
                 description: Source interface names.
-            ssh-filter-profile:
+            ssh_filter_profile:
+                aliases: ['ssh-filter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ssh_filter_profile. Name of an existing SSH filter profile.
-            ssh-policy-redirect:
+                description: Name of an existing SSH filter profile.
+            ssh_policy_redirect:
+                aliases: ['ssh-policy-redirect']
                 type: str
-                description: Deprecated, please rename it to ssh_policy_redirect. Redirect SSH traffic to matching transparent proxy policy.
+                description: Redirect SSH traffic to matching transparent proxy policy.
                 choices:
                     - 'disable'
                     - 'enable'
-            ssl-ssh-profile:
+            ssl_ssh_profile:
+                aliases: ['ssl-ssh-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ssl_ssh_profile. Name of an existing SSL SSH profile.
+                description: Name of an existing SSL SSH profile.
             status:
                 type: str
                 description: Enable/disable the active status of the policy.
@@ -406,89 +452,123 @@ options:
                 type: list
                 elements: str
                 description: Names of user objects.
-            utm-status:
+            utm_status:
+                aliases: ['utm-status']
                 type: str
-                description: Deprecated, please rename it to utm_status. Enable the use of UTM profiles/sensors/lists.
+                description: Enable the use of UTM profiles/sensors/lists.
                 choices:
                     - 'disable'
                     - 'enable'
             uuid:
                 type: str
                 description: Universally Unique Identifier
-            videofilter-profile:
+            videofilter_profile:
+                aliases: ['videofilter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to videofilter_profile. Name of an existing VideoFilter profile.
-            waf-profile:
+                description: Name of an existing VideoFilter profile.
+            waf_profile:
+                aliases: ['waf-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to waf_profile. Name of an existing Web application firewall profile.
+                description: Name of an existing Web application firewall profile.
             webcache:
                 type: str
                 description: Enable/disable web caching.
                 choices:
                     - 'disable'
                     - 'enable'
-            webcache-https:
+            webcache_https:
+                aliases: ['webcache-https']
                 type: str
-                description: Deprecated, please rename it to webcache_https. Enable/disable web caching for HTTPS
+                description: Enable/disable web caching for HTTPS
                 choices:
                     - 'disable'
                     - 'enable'
-            webfilter-profile:
+            webfilter_profile:
+                aliases: ['webfilter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to webfilter_profile. Name of an existing Web filter profile.
-            webproxy-forward-server:
+                description: Name of an existing Web filter profile.
+            webproxy_forward_server:
+                aliases: ['webproxy-forward-server']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to webproxy_forward_server. Web proxy forward server name.
-            webproxy-profile:
+                description: Web proxy forward server name.
+            webproxy_profile:
+                aliases: ['webproxy-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to webproxy_profile. Name of web proxy profile.
-            ztna-ems-tag:
+                description: Name of web proxy profile.
+            ztna_ems_tag:
+                aliases: ['ztna-ems-tag']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ztna_ems_tag. ZTNA EMS Tag names.
-            ztna-proxy:
+                description: ZTNA EMS Tag names.
+            ztna_proxy:
+                aliases: ['ztna-proxy']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to ztna_proxy. IPv4 ZTNA traffic forward proxy.
-            ztna-tags-match-logic:
+                description: IPv4 ZTNA traffic forward proxy.
+            ztna_tags_match_logic:
+                aliases: ['ztna-tags-match-logic']
                 type: str
-                description: Deprecated, please rename it to ztna_tags_match_logic. ZTNA tag matching logic.
+                description: ZTNA tag matching logic.
                 choices:
                     - 'or'
                     - 'and'
-            diameter-filter-profile:
+            diameter_filter_profile:
+                aliases: ['diameter-filter-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to diameter_filter_profile. Name of an existing Diameter filter profile.
-            virtual-patch-profile:
+                description: Name of an existing Diameter filter profile.
+            virtual_patch_profile:
+                aliases: ['virtual-patch-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to virtual_patch_profile. Virtual patch profile.
-            voip-profile:
+                description: Virtual patch profile.
+            voip_profile:
+                aliases: ['voip-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to voip_profile. Name of an existing VoIP profile.
-            dlp-sensor:
+                description: Name of an existing VoIP profile.
+            dlp_sensor:
+                aliases: ['dlp-sensor']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to dlp_sensor. Name of an existing DLP sensor.
-            cifs-profile:
+                description: Name of an existing DLP sensor.
+            cifs_profile:
+                aliases: ['cifs-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to cifs_profile. Name of an existing CIFS profile.
-            internet-service-id:
+                description: Name of an existing CIFS profile.
+            internet_service_id:
+                aliases: ['internet-service-id']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to internet_service_id. Internet Service ID.
-            mms-profile:
+                description: Internet Service ID.
+            mms_profile:
+                aliases: ['mms-profile']
                 type: list
                 elements: str
-                description: Deprecated, please rename it to mms_profile. Name of an existing MMS profile.
+                description: Name of an existing MMS profile.
+            isolator_server:
+                aliases: ['isolator-server']
+                type: list
+                elements: str
+                description: Isolator server name.
+            url_risk:
+                aliases: ['url-risk']
+                type: list
+                elements: str
+                description: URL risk level name.
+            ztna_ems_tag_negate:
+                aliases: ['ztna-ems-tag-negate']
+                type: str
+                description: When enabled, ZTNA EMS tags match against any tag EXCEPT the specified ZTNA EMS tags.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
@@ -514,7 +594,7 @@ EXAMPLES = '''
           _policy_block: <integer>
           access_proxy: <list or string>
           access_proxy6: <list or string>
-          action: <value in [accept, deny, redirect]>
+          action: <value in [accept, deny, redirect, ...]>
           application_list: <list or string>
           av_profile: <list or string>
           block_notification: <value in [disable, enable]>
@@ -597,6 +677,9 @@ EXAMPLES = '''
           cifs_profile: <list or string>
           internet_service_id: <list or string>
           mms_profile: <list or string>
+          isolator_server: <list or string>
+          url_risk: <list or string>
+          ztna_ems_tag_negate: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -640,21 +723,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pblock/{pblock}/firewall/proxy-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pblock/{pblock}/firewall/proxy-policy/{proxy-policy}'
-    ]
-
     url_params = ['adom', 'pblock']
     module_primary_key = 'policyid'
     module_arg_spec = {
@@ -667,7 +743,7 @@ def main():
                 '_policy_block': {'v_range': [['7.6.0', '']], 'type': 'int'},
                 'access-proxy': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
                 'access-proxy6': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
-                'action': {'v_range': [['7.6.0', '']], 'choices': ['accept', 'deny', 'redirect'], 'type': 'str'},
+                'action': {'v_range': [['7.6.0', '']], 'choices': ['accept', 'deny', 'redirect', 'isolate'], 'type': 'str'},
                 'application-list': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
                 'av-profile': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
                 'block-notification': {'v_range': [['7.6.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
@@ -753,9 +829,11 @@ def main():
                 'dlp-sensor': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
                 'cifs-profile': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
                 'internet-service-id': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
-                'mms-profile': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'}
+                'mms-profile': {'v_range': [['7.6.0', '']], 'type': 'list', 'elements': 'str'},
+                'isolator-server': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                'url-risk': {'v_range': [['7.6.2', '']], 'type': 'list', 'elements': 'str'},
+                'ztna-ems-tag-negate': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -769,9 +847,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
