@@ -95,14 +95,16 @@ options:
         required: false
         type: dict
         suboptions:
-            binding-entry:
+            binding_entry:
+                aliases: ['binding-entry']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to binding_entry. Binding entry.
+                description: Binding entry.
                 suboptions:
-                    entry-name:
+                    entry_name:
+                        aliases: ['entry-name']
                         type: str
-                        description: Deprecated, please rename it to entry_name. Configure binding pair.
+                        description: Configure binding pair.
                     ip:
                         type: str
                         description: Source IP for this rule.
@@ -187,23 +189,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/switch-controller/managed-switch/{managed-switch}/ip-source-guard',
         '/pm/config/global/obj/switch-controller/managed-switch/{managed-switch}/ip-source-guard'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/switch-controller/managed-switch/{managed-switch}/ip-source-guard/{ip-source-guard}',
-        '/pm/config/global/obj/switch-controller/managed-switch/{managed-switch}/ip-source-guard/{ip-source-guard}'
-    ]
-
     url_params = ['adom', 'managed-switch']
     module_primary_key = None
     module_arg_spec = {
@@ -227,7 +221,6 @@ def main():
                 'description': {'v_range': [['6.4.0', '6.4.1']], 'type': 'str'},
                 'port': {'v_range': [['6.4.0', '6.4.1']], 'type': 'str'}
             }
-
         }
     }
 
@@ -241,9 +234,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
