@@ -89,21 +89,24 @@ options:
         required: false
         type: dict
         suboptions:
-            allowed-vlans:
+            allowed_vlans:
+                aliases: ['allowed-vlans']
                 type: raw
-                description: (list) Deprecated, please rename it to allowed_vlans. Allowed VLANs to be applied when using this VLAN policy.
-            allowed-vlans-all:
+                description: (list) Allowed VLANs to be applied when using this VLAN policy.
+            allowed_vlans_all:
+                aliases: ['allowed-vlans-all']
                 type: str
-                description: Deprecated, please rename it to allowed_vlans_all. Enable/disable all defined VLANs when using this VLAN policy.
+                description: Enable/disable all defined VLANs when using this VLAN policy.
                 choices:
                     - 'disable'
                     - 'enable'
             description:
                 type: str
                 description: Description for the VLAN policy.
-            discard-mode:
+            discard_mode:
+                aliases: ['discard-mode']
                 type: str
-                description: Deprecated, please rename it to discard_mode. Discard mode to be applied when using this VLAN policy.
+                description: Discard mode to be applied when using this VLAN policy.
                 choices:
                     - 'none'
                     - 'all-untagged'
@@ -112,9 +115,10 @@ options:
                 type: str
                 description: VLAN policy name.
                 required: true
-            untagged-vlans:
+            untagged_vlans:
+                aliases: ['untagged-vlans']
                 type: raw
-                description: (list) Deprecated, please rename it to untagged_vlans. Untagged VLANs to be applied when using this VLAN policy.
+                description: (list) Untagged VLANs to be applied when using this VLAN policy.
             vlan:
                 type: str
                 description: Native VLAN to be applied when using this VLAN policy.
@@ -193,23 +197,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/switch-controller/vlan-policy',
         '/pm/config/global/obj/switch-controller/vlan-policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/switch-controller/vlan-policy/{vlan-policy}',
-        '/pm/config/global/obj/switch-controller/vlan-policy/{vlan-policy}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -225,9 +221,8 @@ def main():
                 'name': {'v_range': [['7.2.1', '']], 'required': True, 'type': 'str'},
                 'untagged-vlans': {'v_range': [['7.2.1', '']], 'type': 'raw'},
                 'vlan': {'v_range': [['7.2.1', '']], 'type': 'str'},
-                'fortilink': {'v_range': [['7.4.3', '']], 'type': 'raw'}
+                'fortilink': {'v_range': [['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'raw'}
             }
-
         }
     }
 
@@ -241,9 +236,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
