@@ -76,10 +76,10 @@ options:
         required: false
         type: dict
         suboptions:
-            entropy-token:
+            entropy_token:
+                aliases: ['entropy-token']
                 type: str
                 description:
-                    - Deprecated, please rename it to entropy_token.
                     - Enable/disable entropy token when switching to FIPS mode.
                     - enable - Enable entropy token.
                     - disable - Disable entropy token.
@@ -88,9 +88,10 @@ options:
                     - 'enable'
                     - 'disable'
                     - 'dynamic'
-            re-seed-interval:
+            re_seed_interval:
+                aliases: ['re-seed-interval']
                 type: int
-                description: Deprecated, please rename it to re_seed_interval. Kernel FIPS-compliant PRNG re-seed interval
+                description: Kernel FIPS-compliant PRNG re-seed interval
             status:
                 type: str
                 description:
@@ -165,21 +166,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/fips'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/fips/{fips}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -191,7 +185,6 @@ def main():
                 're-seed-interval': {'type': 'int'},
                 'status': {'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -205,9 +198,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
