@@ -76,10 +76,10 @@ options:
         required: false
         type: dict
         suboptions:
-            aggressive-fortiview:
+            aggressive_fortiview:
+                aliases: ['aggressive-fortiview']
                 type: str
                 description:
-                    - Deprecated, please rename it to aggressive_fortiview.
                     - Enable/disable auto-cache on fortiview aggressively.
                     - disable - Disable the aggressive fortiview auto-cache.
                     - enable - Enable the aggressive fortiview auto-cache.
@@ -98,10 +98,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            incr-fortiview:
+            incr_fortiview:
+                aliases: ['incr-fortiview']
                 type: str
                 description:
-                    - Deprecated, please rename it to incr_fortiview.
                     - Enable/disable fortiview incremental cache.
                     - disable - Disable the fortiview incremental auto cache.
                     - enable - Enable the fortiview incremental auto cache.
@@ -174,21 +174,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/fortiview/auto-cache'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/fortiview/auto-cache/{auto-cache}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -199,9 +192,8 @@ def main():
                 'aggressive-fortiview': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'interval': {'type': 'int'},
                 'status': {'choices': ['disable', 'enable'], 'type': 'str'},
-                'incr-fortiview': {'v_range': [['7.2.5', '7.2.5'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'incr-fortiview': {'v_range': [['7.2.5', '7.2.9'], ['7.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -215,9 +207,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
