@@ -76,9 +76,10 @@ options:
         required: false
         type: dict
         suboptions:
-            max-alert-count:
+            max_alert_count:
+                aliases: ['max-alert-count']
                 type: int
-                description: Deprecated, please rename it to max_alert_count. Maximum number of alerts supported.
+                description: Maximum number of alerts supported.
 '''
 
 EXAMPLES = '''
@@ -142,21 +143,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/log/alert'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/log/alert/{alert}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -164,7 +158,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'max-alert-count': {'type': 'int'}}
-
         }
     }
 
@@ -178,9 +171,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
