@@ -95,6 +95,9 @@ options:
                 type: int
                 description: ID of device logging disable entry.
                 required: true
+            expire:
+                type: str
+                description: Expire.
 '''
 
 EXAMPLES = '''
@@ -118,6 +121,7 @@ EXAMPLES = '''
           TTL: <string>
           device: <string>
           id: <integer>
+          expire: <string>
 '''
 
 RETURN = '''
@@ -161,21 +165,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/log/device-disable'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/log/device-disable/{device-disable}'
-    ]
-
     url_params = []
     module_primary_key = 'id'
     module_arg_spec = {
@@ -183,11 +180,11 @@ def main():
             'type': 'dict',
             'v_range': [['6.4.4', '']],
             'options': {
-                'TTL': {'v_range': [['6.4.4', '']], 'type': 'str'},
+                'TTL': {'v_range': [['6.4.4', '7.6.1']], 'type': 'str'},
                 'device': {'v_range': [['6.4.4', '']], 'type': 'str'},
-                'id': {'v_range': [['6.4.4', '']], 'required': True, 'type': 'int'}
+                'id': {'v_range': [['6.4.4', '']], 'required': True, 'type': 'int'},
+                'expire': {'v_range': [['7.6.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -201,9 +198,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
