@@ -85,9 +85,10 @@ options:
         required: false
         type: dict
         suboptions:
-            adom-name:
+            adom_name:
+                aliases: ['adom-name']
                 type: str
-                description: Deprecated, please rename it to adom_name. Adom names.
+                description: Adom names.
 '''
 
 EXAMPLES = '''
@@ -152,21 +153,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/global/mc-policy-disabled-adoms'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/global/mc-policy-disabled-adoms/{mc-policy-disabled-adoms}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -174,7 +168,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.2.3', '']],
             'options': {'adom-name': {'v_range': [['6.2.3', '']], 'type': 'str'}}
-
         }
     }
 
@@ -188,9 +181,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
