@@ -113,9 +113,10 @@ options:
                     - 'none'
                     - 'http'
                     - '8bit'
-            msg-type:
+            msg_type:
+                aliases: ['msg-type']
                 type: str
-                description: Deprecated, please rename it to msg_type. Message type.
+                description: Message type.
                 required: true
 '''
 
@@ -200,23 +201,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/replacemsg-group/{replacemsg-group}/webproxy',
         '/pm/config/global/obj/system/replacemsg-group/{replacemsg-group}/webproxy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/replacemsg-group/{replacemsg-group}/webproxy/{webproxy}',
-        '/pm/config/global/obj/system/replacemsg-group/{replacemsg-group}/webproxy/{webproxy}'
-    ]
-
     url_params = ['adom', 'replacemsg-group']
     module_primary_key = 'msg-type'
     module_arg_spec = {
@@ -232,7 +225,6 @@ def main():
                 'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                 'msg-type': {'required': True, 'type': 'str'}
             }
-
         }
     }
 
@@ -246,9 +238,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
