@@ -95,15 +95,18 @@ options:
         required: false
         type: dict
         suboptions:
-            region-list:
+            region_list:
+                aliases: ['region-list']
                 type: raw
-                description: (list) Deprecated, please rename it to region_list. AWS region name list.
-            role-arn:
+                description: (list) AWS region name list.
+            role_arn:
+                aliases: ['role-arn']
                 type: str
-                description: Deprecated, please rename it to role_arn. AWS role ARN to assume.
-            external-id:
+                description: AWS role ARN to assume.
+            external_id:
+                aliases: ['external-id']
                 type: str
-                description: Deprecated, please rename it to external_id. AWS external ID.
+                description: AWS external ID.
 '''
 
 EXAMPLES = '''
@@ -172,23 +175,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/system/sdn-connector/{sdn-connector}/external-account-list',
         '/pm/config/global/obj/system/sdn-connector/{sdn-connector}/external-account-list'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/system/sdn-connector/{sdn-connector}/external-account-list/{external-account-list}',
-        '/pm/config/global/obj/system/sdn-connector/{sdn-connector}/external-account-list/{external-account-list}'
-    ]
-
     url_params = ['adom', 'sdn-connector']
     module_primary_key = None
     module_arg_spec = {
@@ -201,9 +196,8 @@ def main():
             'options': {
                 'region-list': {'v_range': [['7.0.3', '']], 'type': 'raw'},
                 'role-arn': {'v_range': [['7.0.3', '']], 'type': 'str'},
-                'external-id': {'v_range': [['7.0.5', '7.0.12'], ['7.2.1', '']], 'type': 'str'}
+                'external-id': {'v_range': [['7.0.5', '7.0.13'], ['7.2.1', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -217,9 +211,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
