@@ -104,13 +104,14 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            max-packet-count:
+            max_packet_count:
+                aliases: ['max-packet-count']
                 type: int
-                description: Deprecated, please rename it to max_packet_count. Maximum packet count
-            non-ip:
+                description: Maximum packet count
+            non_ip:
+                aliases: ['non-ip']
                 type: str
                 description:
-                    - Deprecated, please rename it to non_ip.
                     - Enable/disable sniffing non-IP packets.
                     - disable - Disable sniffer for non-IP packets.
                     - enable - Enable sniffer for non-IP packets.
@@ -198,21 +199,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/sniffer'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/sniffer/{sniffer}'
-    ]
-
     url_params = []
     module_primary_key = 'id'
     module_arg_spec = {
@@ -230,7 +224,6 @@ def main():
                 'protocol': {'v_range': [['6.2.2', '']], 'type': 'str'},
                 'vlan': {'v_range': [['6.2.2', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -244,9 +237,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
