@@ -92,16 +92,18 @@ options:
             keytab:
                 type: str
                 description: Base64 coded keytab file containing a pre-shared key.
-            ldap-server:
+            ldap_server:
+                aliases: ['ldap-server']
                 type: raw
-                description: (list or str) Deprecated, please rename it to ldap_server. LDAP server name.
+                description: (list or str) LDAP server name.
             name:
                 type: str
                 description: Kerberos keytab entry name.
                 required: true
-            pac-data:
+            pac_data:
+                aliases: ['pac-data']
                 type: str
-                description: Deprecated, please rename it to pac_data. Enable/disable parsing PAC data in the ticket.
+                description: Enable/disable parsing PAC data in the ticket.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -181,23 +183,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/krb-keytab',
         '/pm/config/global/obj/user/krb-keytab'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/krb-keytab/{krb-keytab}',
-        '/pm/config/global/obj/user/krb-keytab/{krb-keytab}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -212,9 +206,8 @@ def main():
                 'name': {'v_range': [['6.2.1', '']], 'required': True, 'type': 'str'},
                 'pac-data': {'v_range': [['6.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'principal': {'v_range': [['6.2.1', '']], 'type': 'str'},
-                'password': {'v_range': [['6.2.2', '7.2.0'], ['7.2.5', '7.2.5'], ['7.4.2', '']], 'no_log': True, 'type': 'raw'}
+                'password': {'v_range': [['6.2.2', '7.2.0'], ['7.2.5', '7.2.9'], ['7.4.2', '']], 'no_log': True, 'type': 'raw'}
             }
-
         }
     }
 
@@ -228,9 +221,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
