@@ -106,9 +106,10 @@ options:
                     vdom:
                         type: str
                         description: Vdom.
-            authen-type:
+            authen_type:
+                aliases: ['authen-type']
                 type: str
-                description: Deprecated, please rename it to authen_type. Authen type.
+                description: Authen type.
                 choices:
                     - 'auto'
                     - 'ascii'
@@ -127,37 +128,48 @@ options:
             port:
                 type: int
                 description: Port.
-            secondary-key:
+            secondary_key:
+                aliases: ['secondary-key']
                 type: raw
-                description: (list) Deprecated, please rename it to secondary_key. Secondary key.
-            secondary-server:
+                description: (list) Secondary key.
+            secondary_server:
+                aliases: ['secondary-server']
                 type: str
-                description: Deprecated, please rename it to secondary_server. Secondary server.
+                description: Secondary server.
             server:
                 type: str
                 description: Server.
-            source-ip:
+            source_ip:
+                aliases: ['source-ip']
                 type: str
-                description: Deprecated, please rename it to source_ip. Source ip.
-            tertiary-key:
+                description: Source ip.
+            tertiary_key:
+                aliases: ['tertiary-key']
                 type: raw
-                description: (list) Deprecated, please rename it to tertiary_key. Tertiary key.
-            tertiary-server:
+                description: (list) Tertiary key.
+            tertiary_server:
+                aliases: ['tertiary-server']
                 type: str
-                description: Deprecated, please rename it to tertiary_server. Tertiary server.
+                description: Tertiary server.
             interface:
                 type: str
                 description: Interface.
-            interface-select-method:
+            interface_select_method:
+                aliases: ['interface-select-method']
                 type: str
-                description: Deprecated, please rename it to interface_select_method. Interface select method.
+                description: Interface select method.
                 choices:
                     - 'auto'
                     - 'sdwan'
                     - 'specify'
-            status-ttl:
+            status_ttl:
+                aliases: ['status-ttl']
                 type: int
-                description: Deprecated, please rename it to status_ttl. Time for which server reachability is cached so that when a server is unreacha...
+                description: Time for which server reachability is cached so that when a server is unreachable, it will not be retried for at least thi...
+            vrf_select:
+                aliases: ['vrf-select']
+                type: int
+                description: VRF ID used for connection to server.
 '''
 
 EXAMPLES = '''
@@ -197,6 +209,7 @@ EXAMPLES = '''
           interface: <string>
           interface_select_method: <value in [auto, sdwan, specify]>
           status_ttl: <integer>
+          vrf_select: <integer>
 '''
 
 RETURN = '''
@@ -240,23 +253,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/user/tacacs+/{tacacs+}/dynamic_mapping',
         '/pm/config/global/obj/user/tacacs+/{tacacs+}/dynamic_mapping'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/user/tacacs+/{tacacs+}/dynamic_mapping/{dynamic_mapping}',
-        '/pm/config/global/obj/user/tacacs+/{tacacs+}/dynamic_mapping/{dynamic_mapping}'
-    ]
-
     url_params = ['adom', 'tacacs+']
     module_primary_key = 'complex:{{module}}["_scope"][0]["name"]+"/"+{{module}}["_scope"][0]["vdom"]'
     module_arg_spec = {
@@ -278,11 +283,11 @@ def main():
                 'source-ip': {'type': 'str'},
                 'tertiary-key': {'no_log': True, 'type': 'raw'},
                 'tertiary-server': {'type': 'str'},
-                'interface': {'v_range': [['6.2.5', '6.2.12'], ['6.4.1', '']], 'type': 'str'},
-                'interface-select-method': {'v_range': [['6.2.5', '6.2.12'], ['6.4.1', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
-                'status-ttl': {'v_range': [['7.4.3', '']], 'type': 'int'}
+                'interface': {'v_range': [['6.2.5', '6.2.13'], ['6.4.1', '']], 'type': 'str'},
+                'interface-select-method': {'v_range': [['6.2.5', '6.2.13'], ['6.4.1', '']], 'choices': ['auto', 'sdwan', 'specify'], 'type': 'str'},
+                'status-ttl': {'v_range': [['7.4.3', '']], 'type': 'int'},
+                'vrf-select': {'v_range': [['7.6.2', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -296,9 +301,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
