@@ -93,16 +93,18 @@ options:
         required: false
         type: dict
         suboptions:
-            _wtp-group:
+            _wtp_group:
+                aliases: ['_wtp-group']
                 type: str
-                description: Deprecated, please rename it to _wtp_group. Wtp group.
+                description: Wtp group.
             id:
                 type: int
                 description: ID.
                 required: true
-            wtp-group:
+            wtp_group:
+                aliases: ['wtp-group']
                 type: str
-                description: Deprecated, please rename it to wtp_group. WTP group name.
+                description: WTP group name.
 '''
 
 EXAMPLES = '''
@@ -171,23 +173,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/wireless-controller/vap/{vap}/vlan-pool',
         '/pm/config/global/obj/wireless-controller/vap/{vap}/vlan-pool'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/wireless-controller/vap/{vap}/vlan-pool/{vlan-pool}',
-        '/pm/config/global/obj/wireless-controller/vap/{vap}/vlan-pool/{vlan-pool}'
-    ]
-
     url_params = ['adom', 'vap']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -199,9 +193,8 @@ def main():
             'options': {
                 '_wtp-group': {'type': 'str'},
                 'id': {'required': True, 'type': 'int'},
-                'wtp-group': {'v_range': [['6.0.0', '6.2.0'], ['7.4.3', '']], 'type': 'str'}
+                'wtp-group': {'v_range': [['6.0.0', '6.2.0'], ['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -215,9 +208,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
