@@ -100,9 +100,10 @@ options:
                     - 'allow'
                     - 'block'
                     - 'erase'
-            case-sensitivity:
+            case_sensitivity:
+                aliases: ['case-sensitivity']
                 type: str
-                description: Deprecated, please rename it to case_sensitivity. Case sensitivity in pattern.
+                description: Case sensitivity in pattern.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -187,19 +188,19 @@ EXAMPLES = '''
           severity: <value in [low, medium, high]>
           status: <value in [disable, enable]>
           target:
-            - arg
-            - arg-name
-            - req-body
-            - req-cookie
-            - req-cookie-name
-            - req-filename
-            - req-header
-            - req-header-name
-            - req-raw-uri
-            - req-uri
-            - resp-body
-            - resp-hdr
-            - resp-status
+            - "arg"
+            - "arg-name"
+            - "req-body"
+            - "req-cookie"
+            - "req-cookie-name"
+            - "req-filename"
+            - "req-header"
+            - "req-header-name"
+            - "req-raw-uri"
+            - "req-uri"
+            - "resp-body"
+            - "resp-hdr"
+            - "resp-status"
 '''
 
 RETURN = '''
@@ -243,23 +244,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/waf/profile/{profile}/signature/custom-signature',
         '/pm/config/global/obj/waf/profile/{profile}/signature/custom-signature'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/waf/profile/{profile}/signature/custom-signature/{custom-signature}',
-        '/pm/config/global/obj/waf/profile/{profile}/signature/custom-signature/{custom-signature}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -286,7 +279,6 @@ def main():
                     'elements': 'str'
                 }
             }
-
         }
     }
 
@@ -300,9 +292,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
