@@ -176,23 +176,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/webfilter/content-header/{content-header}/entries',
         '/pm/config/global/obj/webfilter/content-header/{content-header}/entries'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/webfilter/content-header/{content-header}/entries/{entries}',
-        '/pm/config/global/obj/webfilter/content-header/{content-header}/entries/{entries}'
-    ]
-
     url_params = ['adom', 'content-header']
     module_primary_key = None
     module_arg_spec = {
@@ -203,7 +195,6 @@ def main():
             'type': 'dict',
             'v_range': [['6.0.0', '']],
             'options': {'action': {'choices': ['exempt', 'block', 'allow'], 'type': 'str'}, 'category': {'type': 'raw'}, 'pattern': {'type': 'str'}}
-
         }
     }
 
@@ -217,9 +208,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
