@@ -103,9 +103,10 @@ options:
                 type: int
                 description: ID number.
                 required: true
-            override-replacemsg:
+            override_replacemsg:
+                aliases: ['override-replacemsg']
                 type: str
-                description: Deprecated, please rename it to override_replacemsg. Override replacement message.
+                description: Override replacement message.
             type:
                 type: str
                 description: Quota type.
@@ -195,23 +196,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/webfilter/profile/{profile}/ftgd-wf/quota',
         '/pm/config/global/obj/webfilter/profile/{profile}/ftgd-wf/quota'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/webfilter/profile/{profile}/ftgd-wf/quota/{quota}',
-        '/pm/config/global/obj/webfilter/profile/{profile}/ftgd-wf/quota/{quota}'
-    ]
-
     url_params = ['adom', 'profile']
     module_primary_key = 'id'
     module_arg_spec = {
@@ -229,7 +222,6 @@ def main():
                 'unit': {'choices': ['B', 'KB', 'MB', 'GB'], 'type': 'str'},
                 'value': {'type': 'int'}
             }
-
         }
     }
 
@@ -243,9 +235,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
